from __future__ import annotations

from .b_types import *


class B_PyInventory:
    def __init__(self, /) -> None:
        self.__HasBow: Bool
        self.__HasBowOnBack: Bool
        self.__HasShieldOnBack: Bool
        self.__HoldingBow: Bool
        self.__HoldingShield: Bool
        self.maxObjects: int
        self.maxQuivers: int
        self.maxShields: int
        self.maxWeapons: int
        self.__Name: str
        self.__nKeys: int
        self.__nKindObjects: int
        self.__nObjects: int
        self.__nQuivers: int
        self.__nShields: int
        self.__nSpecialKeys: int
        self.__nTablets: int
        self.__nWeapons: int
        self.__Owner: str

    @property
    def HasBow(self, /):
        """*read only*"""
        return self.__HasBow

    @property
    def HasBowOnBack(self, /):
        """*read only*"""
        return self.__HasBowOnBack

    @property
    def HasShieldOnBack(self, /):
        """*read only*"""
        return self.__HasShieldOnBack

    @property
    def HoldingBow(self, /):
        """*read only*"""
        return self.__HoldingBow

    @property
    def HoldingShield(self, /):
        """*read only*"""
        return self.__HoldingShield

    @property
    def Name(self, /):
        """*read only*"""
        return self.__Name

    @property
    def nKeys(self, /):
        """*read only*"""
        return self.__nKeys

    @property
    def nKindObjects(self, /):
        """*read only*"""
        return self.__nKindObjects

    @property
    def nObjects(self, /):
        """*read only*"""
        return self.__nObjects

    @property
    def nQuivers(self, /):
        """*read only*"""
        return self.__nQuivers

    @property
    def nShields(self, /):
        """*read only*"""
        return self.__nShields

    @property
    def nSpecialKeys(self, /):
        """*read only*"""
        return self.__nSpecialKeys

    @property
    def nTablets(self, /):
        """*read only*"""
        return self.__nTablets

    @property
    def nWeapons(self, /):
        """*read only*"""
        return self.__nWeapons

    @property
    def Owner(self, /):
        """*read only*"""
        return self.__Owner

    def AddBow(self, obj_name: str, unknown: int = 0, /) -> Bool:
        """"""
        ...

    def AddKey(self, obj_name: str, unknown: int = 0, /) -> Bool:
        """"""
        ...

    def AddMagicShield(self, obj_name: str, unknown: int = 0, /) -> Bool:
        """"""
        ...

    def AddObject(self, obj_name: str, unknown: int = 0, /) -> Bool:
        """"""
        ...

    def AddQuiver(self, obj_name: str, unknown: int = 0, /) -> Bool:
        """"""
        ...

    def AddShield(self, obj_name: str, unknown: int = 0, /) -> Bool:
        """"""
        ...

    def AddSpecialKey(self, obj_name: str, unknown: int = 0, /) -> Bool:
        """"""
        ...

    def AddTablet(self, obj_name: str, unknown: int = 0, /) -> Bool:
        """"""
        ...

    def AddWeapon(self, weapon_name: str, flag: Literal[0, 1, 2, 3] = 0, /) -> Bool:
        """
        :flag:
            W_FLAG_1H = 0  # One handed _whatever_ weapon\n
            W_FLAG_2W = 1  # Two handed sword\n
            W_FLAG_AXE = 2  # Two handed axw\n
            W_FLAG_SP = 3  # Two handed spear
        """
        ...

    def CarringObject(self, obj_name: str, /) -> Bool:
        """"""
        ...

    def CycleKeys(self, /) -> None:
        """"""
        ...

    def CycleObjects(self, /) -> None:
        """"""
        ...

    def CycleQuivers(self, /) -> None:
        """"""
        ...

    def CycleShields(self, /) -> None:
        """"""
        ...

    def CycleWeapons(self, /) -> None:
        """"""
        ...

    def GetActiveQuiver(self, /) -> str:
        """"""
        ...

    def GetActiveShield(self, /) -> str:
        """"""
        ...

    def GetActiveWeapon(self, /) -> str:
        """"""
        ...

    def GetBow(self, /) -> str:
        """"""
        ...

    def GetKey(self, obj: Union[int, str], /) -> str:
        """"""
        ...

    def GetLeftBack(self, /) -> str:
        """"""
        ...

    def GetMagicShield(self, /) -> str:
        """"""
        ...

    def GetMaxNumberObjectsAt(self, index: int, /) -> int:
        """"""
        ...

    def GetNumberObjectsAt(self, index: int, /) -> int:
        """"""
        ...

    def GetObject(self, obj: Union[int, str], /) -> str:
        """"""
        ...

    def GetQuiver(self, obj: Union[int, str], /) -> str:
        """"""
        ...

    def GetRightBack(self, /) -> str:
        """"""
        ...

    def GetSelectedKey(self, /) -> str:
        """"""
        ...

    def GetSelectedObject(self, /) -> str:
        """"""
        ...

    def GetSelectedQuiver(self, /) -> str:
        """"""
        ...

    def GetSelectedShield(self, /) -> str:
        """"""
        ...

    def GetSelectedWeapon(self, /) -> str:
        """"""
        ...

    def GetShield(self, obj: Union[int, str], /) -> str:
        """"""
        ...

    def GetSpecialKey(self, obj: Union[int, str], /) -> str:
        """"""
        ...

    def GetTablet(self, obj: Union[int, str], /) -> str:
        """"""
        ...

    def GetWeapon(self, obj: Union[int, str], /) -> str:
        """"""
        ...

    def IsKeySelected(self, index: int, /) -> Bool:
        """"""
        ...

    def IsObjectSelected(self, index: int, /) -> Bool:
        """"""
        ...

    def IsQuiverSelected(self, index: int, /) -> Bool:
        """"""
        ...

    def IsShieldSelected(self, index: int, /) -> Bool:
        """"""
        ...

    def IsWeaponSelected(self, index: int, /) -> Bool:
        """"""
        ...

    def LinkBack(self, obj_name: str, /) -> Bool:
        """
        :obj_name: To unlink use "None"
        """
        ...

    def LinkLeft(self, obj_name: str, /) -> Bool:
        """
        :obj_name: To unlink use "None"
        """
        ...

    def LinkLeftBack(self, obj_name: str, /) -> Bool:
        """
        :obj_name: To unlink use "None"
        """
        ...

    def LinkLeftHand(self, obj_name: str, /) -> Bool:
        """
        :obj_name: To unlink use "None"
        """
        ...

    def LinkLeftHand2(self, obj_name: str, /) -> Bool:
        """
        :obj_name: To unlink use "None"
        """
        ...

    def LinkRight(self, obj_name: str, /) -> Bool:
        """
        :obj_name: To unlink use "None"
        """
        ...

    def LinkRightBack(self, obj_name: str, /) -> Bool:
        """
        :obj_name: To unlink use "None"
        """
        ...

    def LinkRightHand(self, obj_name: str, /) -> Bool:
        """
        :obj_name: To unlink use "None"
        """
        ...

    def RemoveBow(self, obj_name: str, /) -> Bool:
        """"""
        ...

    def RemoveKey(self, obj_name: str, /) -> Bool:
        """"""
        ...

    def RemoveMagicShield(self, obj_name: str, /) -> Bool:
        """"""
        ...

    def RemoveObject(self, obj_name: str, /) -> Bool:
        """"""
        ...

    def RemoveQuiver(self, obj_name: str, /) -> Bool:
        """"""
        ...

    def RemoveShield(self, obj_name: str, /) -> Bool:
        """"""
        ...

    def RemoveSpecialKey(self, obj_name: str, /) -> Bool:
        """"""
        ...

    def RemoveTablet(self, obj_name: str, /) -> Bool:
        """"""
        ...

    def RemoveWeapon(self, obj_name: str, /) -> Bool:
        """"""
        ...

    def SetCurrentQuiver(self, obj_name: str, /) -> Bool:
        """"""
        ...



# Module 'BBLibc'
from __future__ import annotations

import Bladex.__sub__.b_types as __bt


def B_BitMap24_ChangeRGBOrder(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_Clear(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_GetData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_GetDimension(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_ReadFromBMP(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_ReadFromFile(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_ReadFromJPEG(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_SaveToBMP(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_SaveToFile(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_SaveToJPEG(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_CID_ALPHABMP(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_CID_AUTO_OBJDSCR(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_CID_BITMAP(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_CID_BMP(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_CID_OBJDSCR(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_GetFile(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_GetResourceFile(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_GetResourceName(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_GetnFiles(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_IsResourceLoaded(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_LoadResourceToMemory(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_NResources(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_SaveResource(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetConfigDirectory(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetCurrentLanguage(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetResourceManager(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetnOpenInputFiles(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetnOpenedInputFiles(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def LoadAutoBODData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def LoadBOD(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def LoadBODData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def LoadResourceToMemory(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def ReadAutoBOD(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def ReadBOD(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def ReadMMP(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def RemoveOnOpenInputFileFunc(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def ResetnOpenedInputFiles(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def SaveAutoBODData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def SaveBODData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def SetOnOpenInputFileFunc(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_BitMap24(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_BitMap24(*args: __bt.todo) -> __bt.todo:
    """"""
    ...



# Module 'B3DLib'
from __future__ import annotations

import Bladex.__sub__.b_types as __bt


def DiffAngle(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetEntity2EntityAngle(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetXZAngle(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetXZDistance(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetYAngle(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def Modulo(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def Normalize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def Pos2PosXZAngle(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def Pos2PosYAngle(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def Scale(*args: __bt.todo) -> __bt.todo:
    """"""
    ...



# Module 'BInputc'
from __future__ import annotations

import Bladex.__sub__.b_types as __bt


def B_InputAction_AddEvent(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_CurrentlyActivated(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_GetTimeActivated(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_GetnInputEvent(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_IsConst(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_Name(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_RemoveAllEvents(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_RemoveAllProcs(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_RemoveEvent(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_nInputEvents(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_nProcs(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputActions_Find(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputActions_GetAction(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputActions_RemoveAction(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputActions___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputActions_nElements(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputDevice_AddListener(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputDevice_IsBinded(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputDevice_RemoveListener(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputDevice___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputDevice_nListeners(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputListener_EventCallback(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputListener_SetPythonFunc(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputListener___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_AddInputAction(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_AddInputActionsSet(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_AssocKey(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_Bind2(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_GetAttachedDevice(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_GetInputActions(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_GetInputActionsSet(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_GetTimeActionActivated(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_GetTimeActionHeld(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_SetInputActionsSet(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_nInputEvent_GetDevice(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_nInputEvent_GetKey(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_nInputEvent_GetPress(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetInputManager(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_InputManager(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_InputListener(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_InputManager(*args: __bt.todo) -> __bt.todo:
    """"""
    ...



from __future__ import annotations

import typing

# import Bladex
from . import b_object, inventory
from .b_types import *

# Entity.init_entity_properties

__RasterMode = Literal[
    "Full", "Read", "Write", "BlendingAlpha", "AdditiveAlpha", "MultiplyAlpha"
]


class B_Entity:
    def __init__(self, /) -> None:
        self.Actor: Bool
        self.AngVel: float
        self.Arrow: Bool
        self.AttackList: Optional[list]
        self.__CanUse: Bool
        self.ContinuousDamage: int
        self.DamageFunc: Optional[
            Callable[[str, str, str, str, int, int, float, float, float, Bool], Any]
        ]
        self.Data: Any = None
        self.FrameFunc: Optional[Callable[[str, float], Any]] = None
        self.GlowSizeDist: int
        self.GlowTestZ: Bool
        self.HearFunc: Optional[Callable[[str, str, float, float, float, float], Any]]
        self.HitFunc: Optional[
            Callable[
                [
                    str,
                    str,
                    float,
                    float,
                    float,
                    float,
                    float,
                    float,
                    float,
                    float,
                    float,
                    float,
                    float,
                    float,
                ],
                Any,
            ]
        ]
        self.HitShieldFunc: Optional[
            Callable[[str, str, float, float, float, float, float, float, int], Any]
        ]
        self.__InAttack: Bool
        self.__InDestructorAttack: Bool
        self.__InWorld: Bool
        self.InflictHitFunc: Optional[Callable[[str, str, float, float, float], Any]]
        self.Intensity: float
        self.InternalState: Unknown
        self.__Kind: str
        self.Mass: float
        self.__Material: Unknown
        self.__Name: str
        self.__Object: Unknown
        self.__Parent: str
        self.Person: Bool
        self.__Physic: Bool
        self.Position: Vector3
        self.Precission: float
        self.Reflects: int
        self.SeeFunc: Optional[Callable[[str], Any]]
        self.SendSectorMsgs: Bool
        self.SendTriggerSectorMsgs: Bool
        self.SizeFactor: float
        self.Static: Bool
        self.StaticWeaponMode: int
        self.StickFunc: Optional[Callable[[str, str], Any]]
        self.__SubscribedLists: List[str]
        self.TimerFunc: Optional[Callable[[str, float], Any]]
        self.TrailMode: int
        self.UseFunc: Optional[Callable[[str, Literal[0, 2, 4]], Any]]
        self.Weapon: Bool
        self.WeaponMode: int

    # @property
    # def AngVel(self, /):
    #     """*read only*"""
    #     return self.__AngVel

    @property
    def CanUse(self, /):
        """*read only*"""
        return self.__CanUse

    @property
    def InAttack(self, /):
        """*read only*"""
        return self.__InAttack

    @property
    def InDestructorAttack(self, /):
        """*read only*"""
        return self.__InDestructorAttack

    @property
    def InWorld(self, /):
        """*read only*"""
        return self.__InWorld

    # @property
    # def Intensity(self, /):
    #     """*read only*"""
    #     return self.__Intensity

    # @property
    # def InternalState(self, /):
    #     """*read only*"""
    #     return self.__InternalState

    @property
    def Kind(self, /):
        """*read only*"""
        return self.__Kind

    @property
    def Material(self, /):
        """*read only*"""
        return self.__Material

    @property
    def Name(self, /):
        """Modifying this variable is not recommended."""
        return self.__Name

    @Name.setter
    def Name(self, value: str, /):
        self.__Name = value

    @property
    def Object(self, /):
        """*read only*"""
        return self.__Object

    @property
    def Parent(self, /):
        """*read only*"""
        return self.__Parent

    @property
    def Physic(self, /):
        """*read only*"""
        return self.__Physic

    # @property
    # def Precission(self, /):
    #     """*read only*"""
    #     return self.__Precission

    # @property
    # def SizeFactor(self, /):
    #     """*read only*"""
    #     return self.__SizeFactor

    @property
    def SubscribedLists(self, /):
        """*read only*"""
        return self.__SubscribedLists

    # Methods
    def Abs2RelPoint(
        self,
        x: float,
        y: float,
        z: float,
        node_name: Union[NodeType, str_, NULL] = NULL(0),
    ) -> Vector3:
        ...

    @overload
    def Abs2RelVector(self, entity: B_PyEntity, /) -> Vector3:
        ...

    @overload
    def Abs2RelVector(
        self,
        x: float,
        y: float,
        z: float,
        node_name: Union[NodeType, str_, NULL] = NULL(0),
    ) -> Vector3:
        ...

    def Abs2RelVector(self, *args: Any, **kwargs: Any) -> Vector3:
        ...

    def AddAnimSound(
        self, animation: str, sound: b_object.B_PySound, time: float, /
    ) -> Bool:
        ...

    def AddAnmEventFunc(
        self, anm_event: str, func: Callable[[str, str], Any], /
    ) -> Bool:
        ...

    def AddCameraEvent(self, frame: int, func: Callable[[str, int], Any], /) -> Bool:
        ...

    def AddCameraNode(
        self, node: int, time: float, x: float, y: float, z: float, /
    ) -> Bool:
        ...

    def AddEventSound(self, event_name: str, sound: b_object.B_PySound, /) -> Bool:
        ...

    def AddPathNode(self, time: float, x: float, y: float, z: float, /) -> Bool:
        ...

    def AddWatchAnim(self, anm_name: str, /) -> Bool:
        ...

    def CameraClearPath(self, node: int, /) -> Bool:
        ...

    def CameraStartPath(self, node: int, /) -> Bool:
        ...

    def CanGoTo(self, x: float, y: float, z: float, /) -> Bool:
        ...

    def CanISee(self, entity: B_PyEntity, /) -> Bool:
        ...

    def CanISeeFrom(self, entity: B_PyEntity, x: float, y: float, z: float, /) -> Bool:
        ...

    def CatchOnFire(self, x: float, y: float, z: float, /) -> Bool:
        ...

    def Chase(self, enemy: B_PyEntity, action_area: Int, /) -> Bool:
        ...

    def CheckAnimCol(self, anm_name: str, obj: B_PyEntity, unknown: int, /) -> int:
        ...

    def ClearAnmEventFuncs(self, /) -> Bool:
        ...

    def ClearPath(self, /) -> Bool:
        ...

    def Cut(self, /) -> Bool:
        ...

    def DelAnmEventFunc(self, anm_event: str, /) -> Bool:
        ...

    def DoAction(self, action_name: str, /) -> int:
        ...

    def DoActionWI(
        self,
        action_name: str,
        interpolation_type: Literal[0, 1, 2, 3, 4, 5],
        tran_time: float,
        start_timeline: float = 0.0,
        /,
    ) -> int:
        """
        InterpWithOff = 0\n
        InterpWithOutOff = 1\n
        InertialIntrp = 2\n
        FixedRFootIntep = 3\n
        FixedLFootIntep = 4\n
        FixedFootAutoInterp = 5
        """
        ...

    def ExcludeHitFor(self, entity: B_PyEntity, /) -> Bool:
        ...

    def ExcludeHitInAnimationFor(self, entity: B_PyEntity, /) -> Bool:
        ...

    def Face(self, angle: float, /) -> Bool:
        ...

    def Fly(self, velocity_x: float, velocity_y: float, velocity_z: float, /) -> Bool:
        ...

    def Freeze(self, /) -> Bool:
        ...

    def GetActionMode(self, /) -> int:
        ...

    def GetChild(self, index: int, /) -> str:
        ...

    def GetCombatants(self, /) -> List:
        ...

    def GetDummyAxis(
        self,
        anchor_name: str,
        axis_x: float,
        axis_y: float,
        axis_z: float,
        ref: Bool = 1,
        /,
    ) -> Vector3:
        """
        :ref:
            1 - World coordinate\n
            0 - Entity's own coordinate
        """
        ...

    def GetEnemyName(self, /) -> str:
        ...

    def GetGroupMembers(self, /) -> Union[List, Literal[0]]:
        ...

    def GetInventory(self, /) -> inventory.B_PyInventory:
        return inventory.B_PyInventory()

    def GetInventoryEntity(self, *args: Unknown, **kwargs: Unknown) -> Unknown:
        ...

    def GetInventorySelected(self, *args: Unknown, **kwargs: Unknown) -> Unknown:
        ...

    def GetNChildren(self, /) -> int:
        ...

    def GetNodeIndex(self, node_name: str, /) -> int:
        ...

    def GetParticleEntity(self, /) -> B_Entity_Particle:
        return B_Entity_Particle()

    def GetWoundedZone(self, zone: int, /) -> Bool:
        ...

    def GoTo(self, x: float, y: float, z: float, /) -> Bool:
        ...

    def GoToPath(self, i_unknown: int, f_unknown: float, /) -> Bool:
        ...

    def GotAnmType(self, anm_name: str, /) -> Bool:
        ...

    def GraspPos(self, anchor_name: str, /) -> Vector3:
        ...

    def Impulse(self, x: float, y: float, z: float, /) -> Bool:
        ...

    def ImpulseC(
        self, x: float, y: float, z: float, dx: float, dy: float, dz: float, /
    ) -> int:
        ...

    def InsideActionArea(self, action_area: int, /) -> Bool:
        ...

    def InterruptCombat(self, /) -> Bool:
        ...

    def IsValid(self, /) -> Bool:
        ...

    def LaunchAnimation(self, anm_name: str, /) -> Bool:
        ...

    def LaunchAnimation2(self, anm_name1: str, anm_name2: str, /) -> Bool:
        ...

    def LaunchAnmType(self, anm_type: str, index: int = 0, /) -> Bool:
        ...

    def LaunchBayRoute(self, /) -> Bool:
        ...

    def LaunchWatch(self, /) -> Bool:
        ...

    def Link(self, child: B_PyEntity, /) -> Bool:
        ...

    def LinkAnchors(
        self, entity_anchor: str, child: B_PyEntity, child_anchor: str, /
    ) -> Bool:
        ...

    def LinkToNode(self, child: B_PyEntity, node: int, /) -> Bool:
        ...

    @overload
    def LookAt(self, obj_name: str, /) -> Bool:
        ...

    @overload
    def LookAt(self, x: float, y: float, z: float, /) -> Bool:
        ...

    def LookAt(self, *args: Any, **kwargs: Any) -> Bool:
        ...

    def LookAtEntity(self, ent_name: str, /) -> Bool:
        ...

    def LookAtPerson(self, person_name: str, /) -> Bool:
        ...

    @overload
    def MessageEvent(
        self,
        message_type: Literal[0x7, 0x8, 0xD, 0xE, 0xF],
        unknown1: Literal[0],
        unknown2: Literal[0],
        /,
    ) -> int:
        ...

    @overload
    def MessageEvent(self, message_type: int, unknown1: int, unknown2: int, /) -> int:
        ...

    def MessageEvent(self, message_type: int, unknown1: int, unknown2: int, /) -> int:
        """
        :message_type:
            MESSAGE_START_WEAPON = 7\n
            MESSAGE_STOP_WEAPON = 8\n
            MESSAGE_SETSTATICWEPONMODE = 13\n
            MESSAGE_START_TRAIL = 14\n
            MESSAGE_STOP_TRAIL = 15
        """
        ...

    def Move(self, x: float, y: float, z: float, unknown: int = 1, /) -> Bool:
        ...

    def PlaySound(self, cycles: int = -1, /) -> Bool:
        ...

    def PutToWorld(self, /) -> Bool:
        ...

    def QuickFace(self, angle: float, /) -> Bool:
        ...

    @overload
    def RaiseEvent(self, event_name: Literal["Interrupt"], /) -> int:
        ...

    @overload
    def RaiseEvent(self, event_name: str, /) -> int:
        ...

    def RaiseEvent(self, event_name: str, /) -> int:
        ...

    def Rel2AbsPoint(
        self,
        x: float,
        y: float,
        z: float,
        node_name: Union[NodeType, str_, NULL] = NULL(0),
    ) -> Vector3:
        ...

    @overload
    def Rel2AbsVector(self, entity: B_PyEntity, /) -> Vector3:
        ...

    @overload
    def Rel2AbsVector(
        self,
        x: float,
        y: float,
        z: float,
        node_name: Union[NodeType, str_, NULL] = NULL(0),
    ) -> Vector3:
        ...

    def Rel2AbsVector(self, *args: Any, **kwargs: Any) -> Vector3:
        ...

    def RemoveCameraEvent(self, frame: int, /) -> Bool:
        ...

    def RemoveFromInvent(self, obj_name: str, /) -> Bool:
        ...

    def RemoveFromInventLeft(self, /) -> Bool:
        ...

    def RemoveFromInventLeft2(self, /) -> Bool:
        ...

    def RemoveFromInventRight(self, /) -> Bool:
        ...

    def RemoveFromList(self, timer_name: str, /) -> Bool:
        ...

    def RemoveFromWorld(self, /) -> Literal[1]:
        ...

    def RemoveFromWorldWithChilds(self, /) -> Literal[1]:
        ...

    def ResetChase(self, /) -> Bool:
        ...

    def ResetWounds(self, /) -> Bool:
        ...

    def Rotate(
        self,
        axis_x: float,
        axis_y: float,
        axis_z: float,
        angle: float,
        unknown: int = 1,
        /,
    ) -> Bool:
        ...

    def RotateAbs(
        self,
        x: float,
        y: float,
        z: float,
        axis_x: float,
        axis_y: float,
        axis_z: float,
        angle: float,
        unknown: int = 1,
        /,
    ) -> Bool:
        ...

    def RotateRel(
        self,
        x: float,
        y: float,
        z: float,
        axis_x: float,
        axis_y: float,
        axis_z: float,
        angle: float,
        unknown: int = 1,
        /,
    ) -> Bool:
        ...

    def SQDistance2(self, entity: B_PyEntity, /) -> float:
        ...

    def SetActiveEnemy(self, entity: B_PyEntity, /) -> Bool:
        ...

    def SetAnmFlags(
        self,
        anm_name: str,
        wuea: Literal[0, 1, 2],
        mod_y: Bool,
        solf: Bool,
        copy_rot: Bool,
        bng_mov: Literal[0, 1, 2, 3, 4, 5],
        headf: Literal[0, 1, 2, 3],
        /,
    ) -> Bool:
        """
        :bng_mov:
            BM_IDC = 0\n
            BM_NONE = 1\n
            BM_XYZ = 2\n
            BM_XZ = 3\n
            BM_2ANM = 4\n
            BM_SCRIPT = 5
        :headf:
            HEADF_ENG = 0\n
            HEADF_ANM = 1\n
            HEADF_ANM2SEE = 2\n
            HEADF_ANM2ENG = 3
        """
        ...

    def SetAuraActive(self, is_active: int, /) -> Bool:
        ...

    def SetAuraGradient(
        self,
        gap: int,
        r1: float,
        g1: float,
        b1: float,
        alpha1: float,
        starting_point: float,
        r2: float,
        g2: float,
        b2: float,
        alpha2: float,
        ending_point: float,
        /,
    ) -> Bool:
        ...

    def SetAuraParams(
        self,
        size: float,
        alpha: float,
        color_intensity: float,
        hide_front_faces: int,
        hide_back_faces: int,
        alpha_mode: int,
        /,
    ) -> Bool:
        ...

    def SetCameraEndTangentNode(
        self, node: int, node_index: int, tang_x: float, tang_y: float, tang_z: float, /
    ) -> Bool:
        ...

    def SetCameraStartTangentNode(
        self, node: int, node_index: int, tang_x: float, tang_y: float, tang_z: float, /
    ) -> Bool:
        ...

    def SetEnemy(self, enemy: B_PyEntity, /) -> Bool:
        ...

    def SetMaxCamera(self, cam_file_name: str, start: int, end: int, /) -> Bool:
        ...

    def SetMesh(self, mesh_name: str, /) -> Bool:
        ...

    def SetNextAttack(self, attack: str, /) -> int:
        ...

    def SetNodeEndTangent(
        self, unknown1: int, unknown2: float, unknown3: float, unknown4: float, /
    ) -> Bool:
        ...

    def SetNodeStartTangent(
        self, unknown1: int, unknown2: float, unknown3: float, unknown4: float, /
    ) -> Bool:
        ...

    def SetObjectSound(self, sound_name: str, /) -> Bool:
        ...

    def SetOnFloor(self, /) -> int:
        ...

    def SetOrientation(
        self, w: float, x: float, y: float, z: float, unknown: int = 1, /
    ) -> Bool:
        ...

    def SetPersonView(self, person_name: str, /) -> Bool:
        ...

    def SetPosition(self, x: float, y: float, z: float, unknown: int = 1, /) -> Bool:
        ...

    def SetSound(self, file_name: str, /) -> Bool:
        ...

    def SetTmpAnmFlags(
        self,
        wuea: Literal[0, 1, 2],
        mod_y: Bool,
        solf: Bool,
        copy_rot: Bool,
        bng_mov: Literal[0, 1, 2, 3, 4, 5],
        headf: Literal[0, 1, 2, 3],
        unknown: Bool = 1,
        /,
    ) -> Bool:
        """
        :bng_mov:
            BM_IDC = 0\n
            BM_NONE = 1\n
            BM_XYZ = 2\n
            BM_XZ = 3\n
            BM_2ANM = 4\n
            BM_SCRIPT = 5
        :headf:
            HEADF_ENG = 0\n
            HEADF_ANM = 1\n
            HEADF_ANM2SEE = 2\n
            HEADF_ANM2ENG = 3
        """
        ...

    def SetTravellingView(self, s_type: int, t_type: int, /) -> Bool:
        ...

    def SetWoundedZone(self, zone: int, is_active: int, /) -> Bool:
        ...

    def SeverLimb(self, limb: int, /) -> B_Entity_Weapon:
        return B_Entity_Weapon()

    def SlideTo(
        self, final_displacement: float, initial_velocity: float, acceleration: float, /
    ) -> Bool:
        ...

    def StartGrabbing(self, /) -> Bool:
        ...

    def StartLooking(self, x: float, y: float, z: float, /) -> Bool:
        ...

    def StartPath(self, node: int, /) -> Bool:
        ...

    def Stop(self, /) -> Bool:
        ...

    def StopGrabbing(self, /) -> Bool:
        ...

    def StopLooking(self, /) -> Bool:
        ...

    def StopSound(self, /) -> Bool:
        ...

    @overload
    def SubscribeToList(
        self, name: Literal["Pin", "Listeners", "Timer60", "Timer30", "Timer15"], /
    ) -> Bool:
        ...

    @overload
    def SubscribeToList(self, name: str, /) -> Bool:
        ...

    def SubscribeToList(self, name: str, /) -> Bool:
        ...

    def SwitchTo1H(self, /) -> Bool:
        ...

    def SwitchToBow(self, /) -> Bool:
        ...

    def TestPos(
        self, x: float, y: float, z: float, action_area: int, max_fall: float, /
    ) -> int:
        ...

    def TestPosInOwnBox(
        self, x: float, y: float, z: float, box_size: float = 1.0, /
    ) -> int:
        ...

    def TurnOff(self, /) -> Bool:
        ...

    def TurnOn(self, /) -> Bool:
        ...

    def UnFreeze(self, /) -> Bool:
        ...

    def Unlink(self, child: B_PyEntity, /) -> Bool:
        ...

    def UnlinkChildren(self, /) -> Bool:
        ...

    def Use(self, /) -> Bool:
        ...


class B_Entity_(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.Alpha: float
        self.CastShadows: Bool
        self.ExclusionGroup: Bool
        self.__ExclusionMask: Union[int, Literal[1, 2, 4, 8, 32]]
        self.__FireParticleType: Optional[str] = None
        self.FiresIntensity: List[int] = []
        self.__LightColor: Tuple
        self.__LightGlow: Tuple
        self.__LightIntensity: Tuple
        self.__LightPrecission: Tuple
        self.Lights: List[Tuple[float, float, RGBColor]]
        self.Orientation: Quaternion
        self.__RasterModeAlpha: Literal[
            "BlendingAlpha", "AdditiveAlpha", "MultiplyAlpha", None
        ]
        self.__RasterModeZ: Literal["Full", "Read", "Write"]
        self.Scale: float
        self.SelfIlum: float
        self.Solid: Bool
        self.__nFires: int
        self.__nLights: int

    @property
    def ExclusionMask(self, /):
        """
        EX_PERSON = 1\n
        EX_FLOOR = 2\n
        EX_CAMERA = 4\n
        EX_PARTICLES = 8\n
        EX_EYE = 32
        """
        return self.__ExclusionMask

    @ExclusionMask.setter
    def ExclusionMask(self, value: Union[int, Literal[1, 2, 4, 8, 32]], /):
        ...

    @property
    def FireParticleType(self, /):
        """*read only*"""
        return self.__FireParticleType

    @property
    def LightColor(self, /):
        """*read only*"""
        return self.__LightColor

    @property
    def LightGlow(self, /):
        """*read only*"""
        return self.__LightGlow

    @property
    def LightIntensity(self, /):
        """*read only*"""
        return self.__LightIntensity

    @property
    def LightPrecission(self, /):
        """*read only*"""
        return self.__LightPrecission

    @property
    def RasterMode(self, /):
        """*write only*\n
        Use `RasterModeZ`/`RasterModeAlpha` to get.\n
        Default:`Full`, `BlendingAlpha`
        """
        return AttributeError

    @RasterMode.setter
    def RasterMode(self, value: __RasterMode, /):
        ...

    @property
    def RasterModeAlpha(self, /):
        """*read only*\n
        Default:`None`\n
        Use `RasterMode` to set this value.
        """
        return self.__RasterModeAlpha

    @property
    def RasterModeZ(self, /):
        """*read only*\n
        Default:`"Full"`\n
        Use `RasterMode` to set this value.
        """
        return self.__RasterModeZ

    @property
    def nFires(self, /):
        """*read only*"""
        return self.__nFires

    @property
    def nLights(self, /):
        """*read only*"""
        return self.__nLights


class B_Entity_Actor(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.Alpha: float
        self.Animation: str
        self.CastShadows: Bool
        self.__ExclusionMask: Union[int, Literal[1, 2, 4, 8, 32]]
        self.__FireParticleType: Optional[str] = None
        self.FiresIntensity: List[int] = []
        self.Frame: int
        self.__LightColor: Tuple
        self.__LightGlow: Tuple
        self.__LightIntensity: Tuple
        self.__LightPrecission: Tuple
        self.Lights: List[Tuple[float, float, RGBColor]]
        self.OnAnimationEndFunc: Optional[Callable[[str], Any]]
        self.OnPathNodeFunc: Optional[Callable[[str, int], Any]]
        self.Orientation: Quaternion
        self.__RasterModeAlpha: Literal[
            "BlendingAlpha", "AdditiveAlpha", "MultiplyAlpha", None
        ]
        self.__RasterModeZ: Literal["Full", "Read", "Write"]
        self.Scale: float
        self.SelfIlum: float
        self.Solid: Bool
        self.__nFires: int
        self.__nLights: int

    @property
    def ExclusionMask(self, /):
        """
        EX_PERSON = 1\n
        EX_FLOOR = 2\n
        EX_CAMERA = 4\n
        EX_PARTICLES = 8\n
        EX_EYE = 32
        """
        return self.__ExclusionMask

    @ExclusionMask.setter
    def ExclusionMask(self, value: Union[int, Literal[1, 2, 4, 8, 32]], /):
        ...

    @property
    def FireParticleType(self, /):
        """*read only*"""
        return self.__FireParticleType

    @property
    def FPS(self, /):
        """*write only*\n
        e.g: o.FPS = 20.0
        """
        return AttributeError

    @FPS.setter
    def FPS(self, value: Int, /):
        ...

    @property
    def LightColor(self, /):
        """*read only*"""
        return self.__LightColor

    @property
    def LightGlow(self, /):
        """*read only*"""
        return self.__LightGlow

    @property
    def LightIntensity(self, /):
        """*read only*"""
        return self.__LightIntensity

    @property
    def LightPrecission(self, /):
        """*read only*"""
        return self.__LightPrecission

    @property
    def RasterMode(self, /):
        """*write only*\n
        Use `RasterModeZ`/`RasterModeAlpha` to get.\n
        Default:`Full`, `BlendingAlpha`
        """
        return AttributeError

    @RasterMode.setter
    def RasterMode(self, value: __RasterMode, /):
        ...

    @property
    def RasterModeAlpha(self, /):
        """*read only*\n
        Default:`None`\n
        Use `RasterMode` to set this value.
        """
        return self.__RasterModeAlpha

    @property
    def RasterModeZ(self, /):
        """*read only*\n
        Default:`"Full"`\n
        Use `RasterMode` to set this value.
        """
        return self.__RasterModeZ

    @property
    def nFires(self, /):
        """*read only*"""
        return self.__nFires

    @property
    def nLights(self, /):
        """*read only*"""
        return self.__nLights


class B_Entity_Aura(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.Scale: float


class B_Entity_Camera(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.ChangeNodeFunc: Union[Callable[[str, int, int], Any], Literal[""]]
        self.Dist: float
        self.ESource: str
        self.ETarget: str
        self.EarthQuake: Bool
        self.EarthQuakeFactor: float
        self.PViewType: Literal[0, 1, 2, 3]
        self.Returns: Unknown
        self.SType: Literal[0, 1, 2]
        self.Scale: float
        self.TAng: Vector3
        self.TPos: Vector3
        self.TType: Literal[0, 1, 2, 3]


class B_Entity_ElectricBolt(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.Active: Bool
        self.CoreGlowColor: RGBColor
        self.Damage: Bool
        self.ETarget: str
        self.FixedTarget: Bool
        self.InnerGlowColor: RGBColor
        self.MaxAmplitude: float
        self.MinSectorLength: float
        self.OuterGlowColor: RGBColor
        self.Scale: float
        self.SimpleSections: Bool
        self.Target: Vector3


class B_Entity_Fire(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.__FireParticleType: Optional[str] = None
        self.Scale: float

    @property
    def FireParticleType(self, /):
        """*read only*"""
        return self.__FireParticleType


class B_Entity_Lava(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.Scale: float
        self.SelfLight: Bool
        self.TextureName: str
        self.TouchFluidFunc: Optional[Callable[[str, str, float], Any]]
        self.Zoom: float


class B_Entity_Magic_Missile(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.CastShadows: Bool
        self.Color: RGBColor
        self.Damage: Bool
        self.DamageRadius: float
        self.ETarget: str
        self.Flick: Bool
        self.Intensity2: Unknown
        self.OnHitFunc: Optional[Callable[[str, str], Any]]
        self.Scale: float
        self.Velocity: Vector3
        self.Visible: Bool


class B_Entity_Particle(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.DeathTime: float
        self.Friction: float
        self.Friction2: float
        self.Gravity: Vector3
        self.ObjCTest: Bool
        self.PartialLevel: Unknown
        self.Scale: float
        self.Velocity: Vector3


class B_Entity_Particle_System(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.D: Vector3
        self.D1: Vector3
        self.D2: Vector3
        self.DeathTime: float
        self.FollowFactor: float
        self.Friction: float
        self.Friction2: float
        self.NormalVelocity: Int
        self.ObjectName: str
        self.PPS: int
        self.ParticleType: Union[str_, ParticleType]
        self.PersonName: str
        self.PersonNodeName: Union[str_, NodeType]
        self.RandomVelocity: Int
        self.RandomVelocity_V: Int
        self.Scale: float
        self.Time2Live: int
        self.Time2Live_V: int
        self.Velocity: Vector3
        self.YGravity: Int


class B_Entity_Person(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.Accuracy: float
        self.ActionAreaMax: Int
        self.ActionAreaMin: Int
        self.__ActiveEnemy: str
        self.AddBayPoint: Vector3
        self.Aim: Bool
        self.AimOffTarget: Radian
        self.__AimVector: Vector3
        self.Alpha: float
        self.Angle: Radian
        self.__AnimFullName: str
        self.__AnimName: str
        self.AnmEndedFunc: Optional[Callable[[str], Any]]
        self.__AnmPos: float
        self.AnmTranFunc: Optional[Callable[[str], Any]]
        self.__AstarState: Literal[0, 1, 2, 3]
        self.Attack: Bool
        self.AttackFunc: Optional[Callable[[str, str], Any]]
        self.__BayRoute: Bool
        self.BigFallFunc: Optional[Callable[[str, float], Any]]
        self.Blind: Bool
        self.Block: Bool
        self.BlockingPropensity: float
        self.CastShadows: Bool
        self.CharSeeingEnemyFunc: Optional[Callable[[str, str], Any]]
        self.__CharType: str
        self.__CharTypeExt: str
        self.CombatDistFlag: Bool
        self.CombatGroup: str
        self.ContinuousBlock: Bool
        self.__CurrentAreas: Unknown
        self.Deaf: Bool
        self.__DefenceNeeded: Bool
        self.DelayNoSeenFunc: Optional[Callable[[str], Any]]
        self.__Dist2Floor: float
        self.EnemyDeadFunc: Optional[Callable[[str], Any]]
        self.__EnemyLastSeen: Vector3
        self.EnemyNoAllowedAreaFunc: Optional[Callable[[str], Any]]
        self.Energy: float
        self.EnterCloseFunc: Optional[Callable[[str], Any]]
        self.EnterLargeFunc: Optional[Callable[[str], Any]]
        self.EnterPrimaryAAFunc: Optional[Callable[[str], Any]]
        self.EnterSecondaryAAFunc: Optional[Callable[[str], Any]]
        self.ExclusionGroup: Bool
        self.__ExclusionMask: Union[int, Literal[1, 2, 4, 8, 32]]
        self.Frozen: Bool
        self.GoToJogging: Bool
        self.GoToSneaking: Bool
        self.Gob: Bool
        self.Gof: Bool
        self.Heard: Bool
        self.ImDeadFunc: Optional[Callable[[str], Any]]
        self.ImHurtFunc: Optional[Callable[[str], Any]]
        self.__InCombat: Bool
        self.InitPos: Vector3
        self.__InvLeft: str
        self.__InvLeft2: str
        self.__InvLeftBack: str
        self.__InvRight: str
        self.__InvRightBack: str
        self.InvertedRoute: Bool
        self.LastAttackTime: float
        self.__LastSound: str
        self.__LastSoundPosition: Vector3
        self.LastTimeSeen: float
        self.Level: Int
        self.Life: Int
        self.__MeleeActive: Bool
        self.MeshName: str
        self.MutilateFunc: Optional[
            Callable[[str, str, float, float, float, float, float, float, int], Any]
        ]
        self.__MutilationsMask: int
        self.NewComboFunc: Optional[Callable[[str, str], Any]]
        self.NoAllowedAreaFunc: Optional[Callable[[str], Any]]
        self.__OnFloor: bool
        self.OnHitFunc: Optional[Callable[[str, str], Any]]
        self.OnStepFunc: Optional[Callable[[str], Any]]
        self.Orientation: Quaternion
        self.PartialLevel: Int
        self.__PrevAnimName: str
        self.RAttackMax: Int
        self.RAttackMin: Int
        self.__RangeActive: Bool
        self.RangeDefenceCapable: Bool
        self.__RasterModeAlpha: Literal[
            "BlendingAlpha", "AdditiveAlpha", "MultiplyAlpha", None
        ]
        self.__RasterModeZ: Literal["Full", "Read", "Write"]
        self.Returns: Unknown
        self.RouteEndedFunc: Optional[Callable[[str], Any]]
        self.__RouteType: int
        self.Run: Bool
        self.Scale: float
        self.Seen: Bool
        self.SelfIlum: float
        self.Sneak: Bool
        self.TakeFunc: Optional[Callable[[str], Any]]
        self.Texture: Unknown
        self.ThrowFunc: Optional[Callable[[str], Any]]
        self.Tl: Bool
        self.ToggleCombatFunc: Optional[Callable[[str], Any]]
        self.Tr: Bool
        self.__Will1aaTo2aa: Bool
        self.__WillCrashInFloor: Bool
        self.Wuea: Literal[0, 1, 2]

    @property
    def ActiveEnemy(self, /):
        """*read only*"""
        return self.__ActiveEnemy

    @property
    def AimVector(self, /):
        """*read only*"""
        return self.__AimVector

    @property
    def AnimFullName(self, /):
        """*read only*"""
        return self.__AnimFullName

    @property
    def AnimName(self, /):
        """*read only*"""
        return self.__AnimName

    @property
    def AnmPos(self, /):
        """*read only*"""
        return self.__AnmPos

    @property
    def AstarState(self, /):
        """*read only*\n
        non-player attribute"""
        return self.__AstarState

    @property
    def BayRoute(self, /):
        """*read only*"""
        return self.__BayRoute

    @property
    def CharType(self, /):
        """*read only*"""
        return self.__CharType

    @property
    def CharTypeExt(self, /):
        """*read only*"""
        return self.__CharTypeExt

    @property
    def CurrentAreas(self, /):
        """*read only*"""
        return self.__CurrentAreas

    @property
    def DefenceNeeded(self, /):
        """*read only*"""
        return self.__DefenceNeeded

    @property
    def Dist2Floor(self, /):
        """*read only*"""
        return self.__Dist2Floor

    @property
    def EnemyLastSeen(self, /):
        """*read only*"""
        return self.__EnemyLastSeen

    @property
    def ExclusionMask(self, /):
        """
        EX_PERSON = 1\n
        EX_FLOOR = 2\n
        EX_CAMERA = 4\n
        EX_PARTICLES = 8\n
        EX_EYE = 32\n
        Warning: Accessing/modifying this value will cause an error if the character intersects an impenetrable object.
        """
        return self.__ExclusionMask

    @ExclusionMask.setter
    def ExclusionMask(self, value: Union[int, Literal[1, 2, 4, 8, 32]], /):
        ...

    @property
    def InCombat(self, /):
        """*read only*"""
        return self.__InCombat

    @property
    def InvLeft(self, /):
        """*read only*"""
        return self.__InvLeft

    @property
    def InvLeft2(self, /):
        """*read only*"""
        return self.__InvLeft2

    @property
    def InvLeftBack(self, /):
        """*read only*"""
        return self.__InvLeftBack

    @property
    def InvRight(self, /):
        """*read only*"""
        return self.__InvRight

    @property
    def InvRightBack(self, /):
        """*read only*"""
        return self.__InvRightBack

    @property
    def LastSound(self, /):
        """*read only*"""
        return self.__LastSound

    @property
    def LastSoundPosition(self, /):
        """*read only*"""
        return self.__LastSoundPosition

    @property
    def MeleeActive(self, /):
        """*read only*"""
        return self.__MeleeActive

    @property
    def MutilationsMask(self, /):
        """*read only*"""
        return self.__MutilationsMask

    @property
    def OnFloor(self, /):
        """*read only*"""
        return self.__OnFloor

    @property
    def PrevAnimName(self, /):
        """*read only*"""
        return self.__PrevAnimName

    @property
    def RangeActive(self, /):
        """*read only*"""
        return self.__RangeActive

    @property
    def RasterMode(self, /):
        """*write only*\n
        Use `RasterModeZ`/`RasterModeAlpha` to get.\n
        Default:`Full`, `BlendingAlpha`
        """
        return AttributeError

    @RasterMode.setter
    def RasterMode(self, value: __RasterMode, /):
        ...

    @property
    def RasterModeAlpha(self, /):
        """*read only*\n
        Default:`None`\n
        Use `RasterMode` to set this value.
        """
        return self.__RasterModeAlpha

    @property
    def RasterModeZ(self, /):
        """*read only*\n
        Default:`"Full"`\n
        Use `RasterMode` to set this value.
        """
        return self.__RasterModeZ

    @property
    def RouteType(self, /):
        """*read only*\n
        non-player attribute"""
        return self.__RouteType

    @property
    def Will1aaTo2aa(self, /):
        """*read only*"""
        return self.__Will1aaTo2aa

    @property
    def WillCrashInFloor(self, /):
        """*read only*"""
        return self.__WillCrashInFloor


class B_Entity_Physic(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.Alpha: float
        self.AngularVelocity: Vector3
        self.CastShadows: Bool
        self.ExclusionGroup: Bool
        self.__ExclusionMask: Union[int, Literal[1, 2, 4, 8, 32]]
        self.__FireParticleType: Optional[str] = None
        self.FiresIntensity: List[int] = []
        self.Frozen: Bool
        self.Gravity: Vector3
        self.__LightColor: Tuple
        self.__LightGlow: Tuple
        self.__LightIntensity: Tuple
        self.__LightPrecission: Tuple
        self.Lights: List[Tuple[float, float, RGBColor]]
        self.OnStopFunc: Optional[Callable[[str], Any]]
        self.Orientation: Quaternion
        self.__RasterModeAlpha: Literal[
            "BlendingAlpha", "AdditiveAlpha", "MultiplyAlpha", None
        ]
        self.__RasterModeZ: Literal["Full", "Read", "Write"]
        self.Scale: float
        self.SelfIlum: float
        self.Solid: Bool
        self.__TestHit: Bool
        self.Velocity: Vector3
        self.__nFires: int
        self.__nLights: int

    @property
    def ExclusionMask(self, /):
        """
        EX_PERSON = 1\n
        EX_FLOOR = 2\n
        EX_CAMERA = 4\n
        EX_PARTICLES = 8\n
        EX_EYE = 32
        """
        return self.__ExclusionMask

    @ExclusionMask.setter
    def ExclusionMask(self, value: Union[int, Literal[1, 2, 4, 8, 32]], /):
        ...

    @property
    def FireParticleType(self, /):
        """*read only*"""
        return self.__FireParticleType

    @property
    def LightColor(self, /):
        """*read only*"""
        return self.__LightColor

    @property
    def LightGlow(self, /):
        """*read only*"""
        return self.__LightGlow

    @property
    def LightIntensity(self, /):
        """*read only*"""
        return self.__LightIntensity

    @property
    def LightPrecission(self, /):
        """*read only*"""
        return self.__LightPrecission

    @property
    def RasterMode(self, /):
        """*write only*\n
        Use `RasterModeZ`/`RasterModeAlpha` to get.\n
        Default:`Full`, `BlendingAlpha`
        """
        return AttributeError

    @RasterMode.setter
    def RasterMode(self, value: __RasterMode, /):
        ...

    @property
    def RasterModeAlpha(self, /):
        """*read only*\n
        Default:`None`\n
        Use `RasterMode` to set this value.
        """
        return self.__RasterModeAlpha

    @property
    def RasterModeZ(self, /):
        """*read only*\n
        Default:`"Full"`\n
        Use `RasterMode` to set this value.
        """
        return self.__RasterModeZ

    @property
    def TestHit(self, /):
        """*read only*"""
        return self.__TestHit

    @property
    def nFires(self, /):
        """*read only*"""
        return self.__nFires

    @property
    def nLights(self, /):
        """*read only*"""
        return self.__nLights


class B_Entity_Pool(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.Color: RGBColor
        self.DeathTime: float
        self.DeepColor: RGBColor
        self.Scale: float


class B_Entity_Sliding_Area(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.A_D: float
        self.Displacement: float
        self.DisplacementLimit: float
        self.__IsStopped: Bool
        self.OnStopFunc: Optional[Callable[[str], Any]]
        self.Orientation: Quaternion
        self.SlidingSurface: Vector3
        self.V_D: float

    @property
    def IsStopped(self, /):
        """*read only*"""
        return self.__IsStopped


class B_Entity_Sound(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.BaseVolume: float
        self.MaxDistance: float
        self.MinDistance: float
        self.Pitch: float
        self.__Playing: Bool
        self.SendNotify: Bool
        self.Volume: float

    @property
    def Playing(self, /):
        """*read only*"""
        return self.__Playing


class B_Entity_Spark(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.__RasterModeAlpha: Literal[
            "BlendingAlpha", "AdditiveAlpha", "MultiplyAlpha", None
        ]
        self.__RasterModeZ: Literal["Full", "Read", "Write"]
        self.Scale: float

    @property
    def RasterMode(self, /):
        """*write only*\n
        Use `RasterModeZ`/`RasterModeAlpha` to get.\n
        Default:`Full`, `BlendingAlpha`
        """
        return AttributeError

    @RasterMode.setter
    def RasterMode(self, value: __RasterMode, /):
        ...

    @property
    def RasterModeAlpha(self, /):
        """*read only*\n
        Default:`None`\n
        Use `RasterMode` to set this value.
        """
        return self.__RasterModeAlpha

    @property
    def RasterModeZ(self, /):
        """*read only*\n
        Default:`"Full"`\n
        Use `RasterMode` to set this value.
        """
        return self.__RasterModeZ


class B_Entity_Spot(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.CastShadows: Bool
        self.Color: RGBColor
        self.Flick: Bool
        self.__FlickPeriod: float
        self.Intensity2: float
        self.Scale: float
        self.Visible: Bool

    @property
    def FlickPeriod(self, /):
        """B_ENTITYEXT_SPOT_FLICKPERIOD -> Not implemented"""
        return self.__FlickPeriod


class B_Entity_Water(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.Color: RGBColor
        self.Reflection: float
        self.Scale: float
        self.TouchFluidFunc: Optional[Callable[[str, str, float], Any]]
        self.Transparency: float


class B_Entity_Weapon(B_Entity):
    def __init__(self, /) -> None:
        super().__init__()

        self.Alpha: float
        self.AngularVelocity: Vector3
        self.CastShadows: Bool
        self.Cone: float
        self.ExclusionGroup: Bool
        self.__ExclusionMask: Union[int, Literal[1, 2, 4, 8, 32]]
        self.__FireParticleType: Optional[str] = None
        self.FiresIntensity: List[int] = []
        self.Frozen: Bool
        self.Gravity: Vector3
        self.Height: float
        self.__LightColor: Tuple
        self.__LightGlow: Tuple
        self.__LightIntensity: Tuple
        self.__LightPrecission: Tuple
        self.Lights: List[Tuple[float, float, RGBColor]]
        self.OnStopFunc: Optional[Callable[[str], Any]]
        self.Orientation: Quaternion
        self.Radius: float
        self.__RasterModeAlpha: Literal[
            "BlendingAlpha", "AdditiveAlpha", "MultiplyAlpha", None
        ]
        self.__RasterModeZ: Literal["Full", "Read", "Write"]
        self.Scale: float
        self.SelfIlum: float
        self.Solid: Bool
        self.__TestHit: Bool
        self.TrailColor: RGBNormalized
        self.TrailLifeTime: float
        self.Velocity: Vector3
        self.__nFires: int
        self.__nLights: int

    @property
    def ExclusionMask(self, /):
        """
        EX_PERSON = 1\n
        EX_FLOOR = 2\n
        EX_CAMERA = 4\n
        EX_PARTICLES = 8\n
        EX_EYE = 32
        """
        return self.__ExclusionMask

    @ExclusionMask.setter
    def ExclusionMask(self, value: Union[int, Literal[1, 2, 4, 8, 32]], /):
        ...

    @property
    def FireParticleType(self, /):
        """*read only*"""
        return self.__FireParticleType

    @property
    def LightColor(self, /):
        """*read only*"""
        return self.__LightColor

    @property
    def LightGlow(self, /):
        """*read only*"""
        return self.__LightGlow

    @property
    def LightIntensity(self, /):
        """*read only*"""
        return self.__LightIntensity

    @property
    def LightPrecission(self, /):
        """*read only*"""
        return self.__LightPrecission

    @property
    def RasterMode(self, /):
        """*write only*\n
        Use `RasterModeZ`/`RasterModeAlpha` to get.\n
        Default:`Full`, `BlendingAlpha`
        """
        return AttributeError

    @RasterMode.setter
    def RasterMode(self, value: __RasterMode, /):
        ...

    @property
    def RasterModeAlpha(self, /):
        """*read only*\n
        Default:`None`\n
        Use `RasterMode` to set this value.
        """
        return self.__RasterModeAlpha

    @property
    def RasterModeZ(self, /):
        """*read only*\n
        Default:`"Full"`\n
        Use `RasterMode` to set this value.
        """
        return self.__RasterModeZ

    @property
    def TestHit(self, /):
        """*read only*"""
        return self.__TestHit

    @property
    def nFires(self, /):
        """*read only*"""
        return self.__nFires

    @property
    def nLights(self, /):
        """*read only*"""
        return self.__nLights


# 18
class B_PyEntity(
    B_Entity_Actor,
    B_Entity_Aura,
    B_Entity_Camera,
    B_Entity_,
    B_Entity_ElectricBolt,
    B_Entity_Fire,
    B_Entity_Lava,
    B_Entity_Magic_Missile,
    B_Entity_Particle,
    B_Entity_Particle_System,
    B_Entity_Person,
    B_Entity_Physic,
    B_Entity_Pool,
    B_Entity_Sliding_Area,
    B_Entity_Sound,
    B_Entity_Spark,
    B_Entity_Spot,
    B_Entity_Water,
    B_Entity_Weapon,
):
    ...



from __future__ import annotations

from . import entity
from .b_types import *


class B_PyMaterial:
    def __init__(self, /) -> None:
        self.BreakSound: B_PySound
        self.FrictionSound: B_PySound
        self.HitSound: B_PySound
        self.__Name: str
        self.Weight: float

    @property
    def Name(self, /):
        """*read only*"""
        return self.__Name

    def AddHitSoundComb(self, material_name: str, sound: B_PySound, /) -> Bool:
        ...


class B_PyRoute:
    def __init__(self, /) -> None:
        ...

    def AddPoint(self, x: float, y: float, z: float, /) -> Literal[1]:
        ...


class B_PySector:
    def __init__(self, /) -> None:
        self.ActionArea: int
        self.Active: Bool
        self.ActiveSurface: Vector3
        self.BreakInfo: Tuple[Tuple[str, Vector3], ...]
        self.__Index: int
        self.__nSurfaces: int
        self.OnEnter: Optional[Callable[[int, str], Any]]
        self.OnHit: Optional[
            Callable[
                [
                    int,
                    str,
                    float,
                    float,
                    float,
                    float,
                    float,
                    float,
                    float,
                    float,
                    float,
                    str,
                ],
                Any,
            ]
        ]
        self.OnLeave: Optional[Callable[[int, str], Any]]
        self.OnWalkOn: Optional[Callable[[int, str], Any]]
        self.OnWalkOut: Optional[Callable[[int, str], Any]]
        self.TooSteep: Bool
        self.TooSteepAngle: float

    @property
    def Index(self, /):
        """*read only*"""
        return self.__Index

    @property
    def nSurfaces(self, /):
        """*read only*"""
        return self.__nSurfaces

    def DoBreak(self, impulse: Vector3, pos: Vector3, unknown: Vector3, /) -> Bool:
        """
        :unknown: Reference = (0.0, 0.0, 0.0)
        """
        ...

    def GetSelfLight(self, surface_index: int, /) -> float:
        ...

    def GetSpecularLight(self, surface_index: int, /) -> float:
        ...

    def GetSpecularShininess(self, surface_index: int, /) -> float:
        ...

    def GetSurfaceTexture(self, surface_index: int, /) -> str:
        ...

    def GetSurfaceTextureX(self, surface_index: int, /) -> float:
        ...

    def GetSurfaceTextureY(self, surface_index: int, /) -> float:
        ...

    def GetSurfaceTextureZoomX(self, surface_index: int, /) -> float:
        ...

    def GetSurfaceTextureZoomY(self, surface_index: int, /) -> float:
        ...

    def InitBreak(
        self,
        vec1: Vector3,
        vec2: Vector3,
        vec3: Vector3,
        sound_name: str,
        unknown1: float,
        unknown2: int,
        /,
    ) -> Bool:
        ...

    def SetSelfLight(self, surface_index: int, self_light: str, /) -> Bool:
        ...

    def SetSpecularLight(self, surface_index: int, specular_light: str, /) -> Bool:
        ...

    def SetSpecularShininess(
        self, surface_index: int, specular_shininess: str, /
    ) -> Bool:
        ...

    def SetSurfaceTexture(self, surface_index: int, texture: str, /) -> Bool:
        ...

    def SetSurfaceTextureX(self, surface_index: int, texture_x: float, /) -> Bool:
        ...

    def SetSurfaceTextureY(self, surface_index: int, texture_y: float, /) -> Bool:
        ...

    def SetSurfaceTextureZoomX(self, surface_index: int, zoom_x: float, /) -> Bool:
        ...

    def SetSurfaceTextureZoomY(self, surface_index: int, zoom_y: float, /) -> Bool:
        ...


class B_PySound:
    def __init__(self, /) -> None:
        self.BaseVolume: float
        self.MaxDistance: float
        self.MinDistance: float
        self.__Name: str
        self.Pitch: float
        self.Scale: float
        self.SendNotify: Bool
        self.Volume: float

    @property
    def Name(self, /):
        """*read only*"""
        return self.__Name

    def AddAltSound(self, alt_sound: str, /) -> Bool:
        ...

    def Play(self, x: float, y: float, z: float, cycles: int = 0, /) -> Bool:
        ...

    def PlayStereo(self, cycles: int = 0, /) -> Bool:
        ...

    def SetPitchVar(
        self,
        i_unknown: int,
        f_unknown1: float,
        f_unknown2: float,
        f_unknown3: float,
        f_unknown4: float,
        /,
    ) -> Literal[1]:
        """
        e.g: SetPitchVar(1, -8000, 8000, 0, 0)
        """
        ...

    def Stop(self, /) -> Bool:
        ...


class B_PyTrail:
    def __init__(self, /) -> None:
        self.Color: RGBColor
        self.ShrinkFactor: float
        self.Time2Live: float
        self.Transparency: float



from __future__ import annotations

import typing
from typing import (
    Any,
    AnyStr,
    Callable,
    Dict,
    List,
    Literal,
    Optional,
    Tuple,
    Union,
    overload,
)

# Any_ = Union[Any, None]
Bool = Union[bool, Literal[0, 1]]
Int = Union[int, float]
Quaternion = Tuple[float, float, float, float]
Radian = float
RGBColor = Tuple[int, int, int]
RGBNormalized = Tuple[float, float, float]
Vector2 = Tuple[float, float]
Vector3 = Tuple[float, float, float]

Unknown = Any
str_ = Any
todo = Any
# Unknown = Union[Any, Any]
# str_ = Union[Any, Any]
# todo = Union[Any, Any]
NULL = typing.NewType("NULL", int)

NodeType = Literal[
    "Center",
    "Chest",
    "Head",
    "R_Shoulder",
    "R_Arm",
    "R_Elbow",
    "R_Forearm",
    "R_Wrist",
    "R_Hand",
    "L_Shoulder",
    "L_Arm",
    "L_Elbow",
    "L_Forearm",
    "L_Wrist",
    "L_Hand",
    "R_Ass",
    "R_Leg",
    "R_Knee",
    "R_Boot",
    "R_Foot",
    "L_Ass",
    "L_Leg",
    "L_Knee",
    "L_Boot",
    "L_Foot",
]

Builtin_Kind = Literal[
    "Entity Aura",
    "Entity Camera",
    "Entity Dynamic Fire",
    "Entity ElectricBolt",
    "Entity Fire",
    "Entity Lava",
    "Entity Magic Missile",
    "Entity Particle",
    "Entity Particle System D1",
    "Entity Particle System D2",
    "Entity Particle System D3",
    "Entity Particle System Dobj",
    "Entity Particle System Dperson",
    "Entity Pool",
    "Entity Sliding Area",
    "Entity Sound",
    "Entity Spot",
    "Entity Water",
]

ParticleType = Literal[
    "AnkBlood",
    "BigFire",
    "BladeSwordMissile",
    "Blood",
    "BlueMagicMissile",
    "BlueSpark",
    "BlueTrail",
    "BrillosBladeSword",
    "DGLevelUpParticle",
    "DGLifeUpEnergyConc",
    "DLLevelUpParticle",
    "DLLifeUpEnergyConc",
    "DarkSmoke",
    "DeathCloud",
    "DeepGreenEnergyConc",
    "DeepGreenMagicMissile",
    "DeepOrangeEnergyConc",
    "DeepOrangeMagicMissile",
    "DeepRedEnergyConc",
    "DeepRedMagicMissile",
    "DemonShield",
    "Dust",
    "Energia2",
    "Energia3",
    "EnergyConc",
    "EnergyDissip",
    "FastEnergyConc",
    "FastRedEnergyConc",
    "Fire",
    "Flame",
    "FuegoInvocacion",
    "GDLevelUpParticle",
    "GDLifeUpEnergyConc",
    "GasVenenoso",
    "GasVenenoso2",
    "GotasSangre",
    "GreenBlood",
    "GreenFire",
    "GreenTrail",
    "GreyBlood",
    "LargeDust",
    "LargeFire",
    "LargeFlame",
    "LevelUpParticle",
    "LittleBlueEnergyConc",
    "LittleBlueSpark",
    "LittleDeepOrangeMagicMissile",
    "LittleEnergyDissip",
    "Llamita",
    "Llamita2",
    "LucesCools",
    "MediumDust",
    "Miguillas",
    "MulticolourEnergyDissip",
    "RedMagicMissile",
    "RedTrail",
    "SacredFX",
    "Sand",
    "ShitSmoke",
    "Smoke",
    "SnowDust",
    "Splinter",
    "Vaho",
    "Venom",
    "VenomSmoke",
    "Vomit",
    "WhiteTrail",
    "YellowTrail",
]

BodList = Literal[
    "Amz_Bng",
    "Amazon_L",
    "Amazon_N",
    "AmzSkin1",
    "DarkLord",
    "Ank2",
    "Ank_Bng",
    "Barbarian",
    "Bar_Bng",
    "Barbarian_L",
    "Barbarian_N",
    "BarSkin1",
    "Bat",
    "ChaosKnight",
    "Chk_Bng",
    "Cos",
    "Cos_Bng",
    "Crw",
    "DalGurak",
    "Dgk_Bng",
    "Dark_Knight",
    "Dkn_Bng",
    "Dark_Ork",
    "Dok_Bng",
    "Dragon",
    "Dwf_Bng",
    "Dwarf_L",
    "Dwarf_M",
    "Dwarf_N",
    "DwfSkin1",
    "Ena_Bng",
    "Enano1",
    "Enano2",
    "Enano3",
    "Enano4",
    "Gargoyle_Stone_Form",
    "Great_Demon",
    "Gdm_Bng",
    "Glm_Bng",
    "Golem_clay",
    "Golem_lava",
    "Golem_metal",
    "Golem_stone",
    "Great_Ork",
    "Gok_Bng",
    "Kgt_Bng",
    "Knight_F",
    "Knight_L",
    "Knight_M",
    "Knight_N",
    "Knight_traitor",
    "KgtSkin1",
    "Lich",
    "Lch_Bng",
    "Little_Demon",
    "Ldm_Bng",
    "Minotaur",
    "Min_Bng",
    "Gold_Ork",
    "Org_Bng",
    "Ork",
    "Ork_Bng",
    "Pio",
    "Prisoner_1",
    "Prisoner_2",
    "Prisoner_3",
    "Prisoner_4",
    "Prisoner_5",
    "Prisoner_6",
    "Prs_Bng",
    "Rat",
    "Ragnar",
    "Rgn_Bng",
    "Sgl",
    "Shank",
    "Shn_Bng",
    "Skeleton",
    "Skl_Bng",
    "Skeleton_Optimiced",
    "Salamander",
    "Slm_Bng",
    "Spidersmall",
    "Spd_Bng",
    "Knight_Traitor",
    "Tkn_Bng",
    "Trl_Bng",
    "Troll_Dark",
    "Troll_snow",
    "Vejete",
    "Vamp",
    "Vmp_Bng",
    "Wyvern",
    "Knight_Zombie",
    "Zkn_Bng",
    "Duque",
    "Mortimer",
    "NP_Knight",
    "Golem_ice",
    "BarSkin2",
    "KgtSkin2",
    "AmzSkin2",
    "DwfSkin2",
    "Adoquinpulsador",
    "Adoquinpulsador2",
    "AdoquinRuna",
    "AdoquinRuna2",
    "AdoquinRuna3",
    "Agarramanos",
    "Agarrapies",
    "Alabarda",
    "AlabardaPieza1",
    "AlabardaPieza2",
    "Alfanje",
    "AlfanjePieza1",
    "AlfanjePieza2",
    "AlfanjePieza3",
    "Alfeizar",
    "Alforjas",
    "Altar",
    "AltarPieza1",
    "AltarPieza10",
    "AltarPieza11",
    "AltarPieza12",
    "AltarPieza13",
    "AltarPieza14",
    "AltarPieza15",
    "AltarPieza16",
    "AltarPieza17",
    "AltarPieza18",
    "AltarPieza19",
    "AltarPieza2",
    "AltarPieza20",
    "AltarPieza3",
    "AltarPieza4",
    "AltarPieza5",
    "AltarPieza6",
    "AltarPieza7",
    "AltarPieza8",
    "AltarPieza9",
    "Amuletofantasma",
    "Amuleto",
    "Amuletoserpiente",
    "Amazon_Head",
    "AnilloFoso",
    "AntorchaAtlante",
    "Antidoto",
    "Antorcha2",
    "Antorcha",
    "Lamparacobra",
    "Antorchaenpared",
    "ArbolNevado2",
    "Arbolseco",
    "Arbolseco2",
    "Arco",
    "Arco2",
    "Arco3",
    "Arco_Amz_seleccion",
    "Argolla",
    "Armadura",
    "ArmaduraAmazonaLigera",
    "ArmaduraBarbaroLigera",
    "ArmaduraEnanoLigera",
    "ArmaduraEnanoMedia",
    "ArmaduraCaballeroCompleta",
    "ArmaduraCaballeroLigera",
    "ArmaduraCaballeroMedia",
    "ArmaduraBlade",
    "Armero",
    "Armero2",
    "Armero2Pieza1",
    "Armero2Pieza2",
    "Armero2Pieza3",
    "Armero2Pieza4",
    "Armero2Pieza5",
    "ArmeroPieza1",
    "ArmeroPieza2",
    "ArmeroPieza3",
    "ArmeroPieza4",
    "AroMagico",
    "Arpon",
    "ArponPieza1",
    "ArponPieza2",
    "ArponPieza3",
    "ArponPieza4",
    "Atril",
    "Axe_Dwf_seleccion",
    "Axpear",
    "AxpearPieza1",
    "AxpearPieza2",
    "AxpearPieza3",
    "AxpearPieza4",
    "Baldosa_01",
    "Baldosa_rota",
    "Banco",
    "BancoPieza1",
    "BancoPieza2",
    "BancoPieza3",
    "BancoPieza4",
    "Bandeja",
    "Barbarian_Head_1",
    "Barbarian_Head_2",
    "BarroteAurelio",
    "Barril",
    "BaseCono",
    "Baston",
    "Baston2",
    "Baston3",
    "Bichero",
    "BicheroPieza1",
    "BicheroPieza2",
    "BicheroPieza3",
    "BigSword",
    "BigSwordPieza1",
    "BigSwordPieza2",
    "BigSwordPieza3",
    "LlaveNegra",
    "BladeSword",
    "BladeSword2",
    "BladeSword2Barbarian",
    "BladeSword2Poly",
    "BladeSwordBarbarian",
    "BladeSwordPoly",
    "BlasonAurelio",
    "Blason1",
    "Blason2",
    "Blason3",
    "Blason4",
    "Blason5",
    "Blason6",
    "Bloodbol",
    "Bloque",
    "BloqueManu",
    "BloqueTallado",
    "LlaveAzul",
    "Bo",
    "Boingtotem2",
    "BolaDalGurak",
    "BoladePiedra",
    "BolaRayos",
    "BoPieza1",
    "BoPieza2",
    "Botella",
    "BotellaVerde",
    "BotellaSagrada",
    "BarrilPieza1",
    "BarrilPieza2",
    "BarrilPieza3",
    "BarrilPieza4",
    "BarrilPieza5",
    "BarrilPieza6",
    "Brasero1",
    "Braseroarana",
    "Brazalete",
    "LlaveMarron",
    "ButacaMago",
    "CabezaFernando",
    "Cabezon",
    "CabezaSerpiente",
    "Caja_i_i",
    "Caja_i_r",
    "Cajama",
    "Cajon",
    "Cajon2",
    "Caliz",
    "Camabad",
    "Camapaja",
    "Camastro",
    "Camavampiro",
    "Campana",
    "CandilAurelio",
    "Candelabro",
    "Candelpeque",
    "Candil",
    "Candil2",
    "Canica",
    "Cantimplora",
    "Carburo",
    "Carcaj",
    "Carcaj_Amz_seleccion",
    "Carcaj_E",
    "CarcajEnvenenado",
    "CarcajEnvenenado_E",
    "CarcajFuego",
    "CarcajFuego_E",
    "Carretilla",
    "CascoBlade",
    "Casco1",
    "Casco2",
    "Casco3",
    "Casco4",
    "Casco5",
    "Cazo",
    "Cebolla",
    "Cepo",
    "Cerbatana",
    "CerraduraBlade",
    "Cerradura",
    "Cerraduracobox",
    "Cerraduracutre",
    "Cerradurcob",
    "Cerradurdor",
    "Cerradurpla",
    "Chakram",
    "Chakram2",
    "Chakram2Pieza1",
    "Chakram2Pieza2",
    "ChakramPieza1",
    "ChakramPieza2",
    "Chaosword",
    "ChaoswordPieza1",
    "ChaoswordPieza2",
    "ChispasBladeSword",
    "CilindroMagico",
    "CilindroMagico2",
    "CilindroTransportador",
    "Cimitarra",
    "CimitarraPieza1",
    "CimitarraPieza2",
    "Cincel",
    "Cirio",
    "CajamaPieza1",
    "CajamaPieza10",
    "CajamaPieza11",
    "CajamaPieza12",
    "CajamaPieza13",
    "CajamaPieza14",
    "CajamaPieza15",
    "CajamaPieza16",
    "CajamaPieza17",
    "CajamaPieza18",
    "CajamaPieza2",
    "CajamaPieza3",
    "CajamaPieza4",
    "CajamaPieza5",
    "CajamaPieza6",
    "CajamaPieza7",
    "CajamaPieza8",
    "CajamaPieza9",
    "Cofre",
    "Cofrepeque",
    "CofrePieza1",
    "CofrePieza2",
    "CofrePieza3",
    "ColaSerpiente",
    "Columnaestrecha",
    "Columna",
    "Cono1",
    "Coraza1",
    "Coraza2",
    "Coraza3",
    "CorazaBlade",
    "Corona",
    "Costilla",
    "CajonPieza1",
    "CajonPieza10",
    "CajonPieza11",
    "CajonPieza12",
    "CajonPieza13",
    "CajonPieza14",
    "CajonPieza15",
    "CajonPieza16",
    "CajonPieza17",
    "CajonPieza18",
    "CajonPieza2",
    "CajonPieza3",
    "CajonPieza4",
    "CajonPieza5",
    "CajonPieza6",
    "CajonPieza7",
    "CajonPieza8",
    "CajonPieza9",
    "Cracorn1",
    "Cracorn2",
    "CraneoCornudo3",
    "CraneoCornudo4",
    "CristalMineral",
    "Crosspear",
    "CrosspearPieza1",
    "CrosspearPieza2",
    "CrosspearPieza3",
    "CrosspearPieza4",
    "CrushBo",
    "CrushBoPieza1",
    "CrushBoPieza2",
    "CrushBoPieza3",
    "CrushHammer",
    "CrushHammerPieza1",
    "CrushHammerPieza2",
    "CrushHammerPieza3",
    "Cubo",
    "CuchillaFernando",
    "Cuchillo",
    "CuchilloPieza1",
    "CuchilloPieza2",
    "Cuerda",
    "CuerdaLarguisima",
    "CuerdasPuenteFernando",
    "Cupula",
    "Daga",
    "DagaPieza1",
    "DagaPieza2",
    "Dagarrojar",
    "DagarrojarPieza1",
    "DagarrojarPieza2",
    "Dagesse",
    "DagessePieza1",
    "DagessePieza2",
    "DalBlade",
    "DalShield",
    "DalShieldPieza1",
    "DalShieldPieza2",
    "DalShieldPieza3",
    "DalWeapon",
    "DalWeaponPieza1",
    "DalWeaponPieza2",
    "Dardo",
    "DeathBo",
    "DeathBoPieza1",
    "DeathBoPieza2",
    "DeathBoPieza3",
    "DeathKatar",
    "DeathKatarPieza1",
    "DeathKatarPieza2",
    "DeathSword",
    "DeathSwordPieza1",
    "DeathSwordPieza2",
    "DoubleSword",
    "DoubleSwordPieza1",
    "DoubleSwordPieza2",
    "DoubleSwordPieza3",
    "DoubleSwordPieza4",
    "Dragon_estatua",
    "Dragonsw",
    "Eclipse",
    "EclipsePieza1",
    "EclipsePieza2",
    "EgyptSword",
    "EgyptSwordPieza1",
    "EgyptSwordPieza2",
    "Elefante",
    "EscudoBlade2",
    "Escblade3",
    "EscudoBlade",
    "Escudo1",
    "Escudo1Pieza1",
    "Escudo1Pieza2",
    "Escudo2",
    "Escudo2Pieza1",
    "Escudo2Pieza2",
    "Escudo3",
    "Escudo3Pieza1",
    "Escudo3Pieza2",
    "Escudo4",
    "Escudo4Pieza1",
    "Escudo4Pieza2",
    "Escudo5",
    "Escudo5Pieza1",
    "Escudo5Pieza2",
    "Escudo6",
    "Escudo6Pieza1",
    "Escudo6Pieza2",
    "Escudo6Pieza3",
    "Escudo7",
    "Escudo7Pieza1",
    "Escudo7Pieza2",
    "Escudo8",
    "Escudo8Pieza1",
    "Escudo8Pieza2",
    "Escudo8Pieza3",
    "Escudo8x8",
    "Escudo9",
    "Escudo9Pieza1",
    "Escudo9Pieza2",
    "Escudo9Pieza3",
    "Escudon",
    "EscudonPoly",
    "Escudonx6",
    "EsferaGemaAzul",
    "EsferaGemaRoja",
    "EsferaGemaVerde",
    "EsferaNegra",
    "EsferaOrbital",
    "Escudobollado1",
    "Escudobollado2",
    "Eslabon1",
    "Eslabon2",
    "Eslabon3",
    "Espadacurva",
    "Espada",
    "Espada_Bar_seleccion",
    "EspadacurvaPieza1",
    "EspadacurvaPieza2",
    "EspadaelficaPieza1",
    "EspadaelficaPieza2",
    "EspadafiloPieza1",
    "EspadafiloPieza2",
    "EspadaMagica1Pieza1",
    "EspadaMagica1Pieza2",
    "EspadaMagica2Pieza1",
    "EspadaMagica2Pieza2",
    "EspadaMagica3Pieza1",
    "EspadaMagica3Pieza2",
    "EspadaPieza1",
    "EspadaPieza2",
    "EspadaromanaPieza1",
    "EspadaromanaPieza2",
    "Espadaelfica",
    "Espadon",
    "EspadonPoly",
    "Espadafilo",
    "Espadaromana",
    "Espectro",
    "EspadaMagica1",
    "EspadaMagica2",
    "EspadaMagica3",
    "EsqueletoPieza1",
    "EsqueletoPieza10",
    "EsqueletoPieza2",
    "EsqueletoPieza3",
    "EsqueletoPieza4",
    "EsqueletoPieza5",
    "EsqueletoPieza6",
    "EsqueletoPieza7",
    "EsqueletoPieza8",
    "EsqueletoPieza9",
    "Esquirla",
    "Estaca",
    "EstacaFernando",
    "Estalact1",
    "Estalact2",
    "EstatuaGolem",
    "Farol",
    "Farol2",
    "Femur",
    "Fetiche",
    "FireAxe",
    "FireAxePieza1",
    "FireAxePieza2",
    "FireAxePieza3",
    "BoladeFuego",
    "BoladeFuego2",
    "BolitadeFuego",
    "FireBigSword",
    "FireBigSwordPieza1",
    "FireBigSwordPieza2",
    "FireBigSwordPieza3",
    "FireBo",
    "FireBoPieza1",
    "FireBoPieza2",
    "FireRing",
    "FireSword",
    "FireSwordPieza1",
    "FireSwordPieza2",
    "FireSwordPieza3",
    "FireSwordPieza4",
    "BolilladeFuego",
    "FlatSword",
    "FlatSwordPieza1",
    "FlatSwordPieza2",
    "Flecha",
    "Flecha_Amz_seleccion",
    "FlechaEnvenenada",
    "FlechaFuego",
    "Fuelle",
    "GanchoAurelio",
    "Gancho",
    "Garfio",
    "Garfio2",
    "Garfio3",
    "GargolaFernando",
    "Gargola02",
    "Gargola",
    "GargolaNevada",
    "Garropin",
    "GarropinPieza1",
    "GarropinPieza2",
    "Garrote",
    "Garrote2",
    "Garrote2Pieza1",
    "Garrote2Pieza2",
    "GarrotePieza1",
    "GarrotePieza2",
    "Gema",
    "Gemaazul",
    "Gemapurpura",
    "Gemaroja",
    "Geoda",
    "GeodaPieza1",
    "GeodaPieza2",
    "GeodaPieza3",
    "GeodaPieza4",
    "GeodaPieza5",
    "GhostPointer",
    "Gladius",
    "GladiusPieza1",
    "GladiusPieza2",
    "GladiusSeleccion",
    "Globo",
    "Gozne",
    "Grifoserpiente",
    "Guadanya",
    "GuadanyaPieza1",
    "GuadanyaPieza2",
    "GuadanyaPieza3",
    "Hacha",
    "Hacha2",
    "Hacha2hojas",
    "Hacha2hojasPieza1",
    "Hacha2hojasPieza2",
    "Hacha2hojasPieza3",
    "Hacha2Pieza1",
    "Hacha2Pieza2",
    "Hacha3",
    "Hacha3Pieza1",
    "Hacha3Pieza2",
    "Hacha4",
    "Hacha4Pieza1",
    "Hacha4Pieza2",
    "Hacha5",
    "Hacha5Pieza1",
    "Hacha5Pieza2",
    "Hacha6",
    "Hacha6Pieza1",
    "Hacha6Pieza2",
    "Hachacarnicero",
    "HachacarniceroPieza1",
    "HachacarniceroPieza2",
    "HachacarniceroPieza3",
    "HachacarniceroPieza4",
    "HachacuchillaPieza1",
    "HachacuchillaPieza2",
    "HachaPieza1",
    "HachaPieza2",
    "Hacharrajada",
    "HacharrajadaPieza1",
    "HacharrajadaPieza2",
    "HacharrajadaPieza3",
    "Hachacuchilla",
    "Halcon",
    "Halcon2",
    "ElefantePartido",
    "HalfmoonTrail",
    "MartilloForja",
    "Helice",
    "Hogaza",
    "Hoguera",
    "HookSword",
    "HookSwordPieza1",
    "HookSwordPieza2",
    "HookSwordPieza3",
    "HookSwordPieza4",
    "Hornacina",
    "IceAxe",
    "IceAxePieza1",
    "IceAxePieza2",
    "IceAxePieza3",
    "IceAxePieza4",
    "IceAxePieza5",
    "IceHammer",
    "IceHammerPieza1",
    "IceHammerPieza2",
    "IceHammerPieza3",
    "IceHammerPieza4",
    "IceHammerPieza5",
    "IceHammerPieza6",
    "IceSword",
    "IceSwordPieza1",
    "IceSwordPieza2",
    "IceSwordPieza3",
    "IceSwordPieza4",
    "IceWandPieza1",
    "IceWandPieza2",
    "IceWandPieza3",
    "Jar_Dwf_seleccion",
    "Jarra",
    "Jarrita",
    "Jaula",
    "Katana",
    "KatanaPieza1",
    "KatanaPieza2",
    "Katar",
    "KatarDoble",
    "KatarDoblePieza1",
    "KatarDoblePieza2",
    "KatarDoblePieza3",
    "KatarDoblePieza4",
    "Katarmoon",
    "KatarmoonPieza1",
    "KatarmoonPieza2",
    "KatarmoonPieza3",
    "KatarmoonPieza4",
    "KatarPieza1",
    "KatarPieza2",
    "KatarPieza3",
    "Keysup",
    "KingShield",
    "KingShieldPieza1",
    "KingShieldPieza2",
    "KingShieldPieza3",
    "KingSword",
    "KingSwordPieza1",
    "KingSwordPieza2",
    "KingSwordPieza3",
    "LamparaKongo",
    "Lamparatecho",
    "LamparaNegra",
    "Lampared",
    "LamparaAurelio",
    "Lampcolg",
    "Lamparaegipto",
    "Gancholamp",
    "LamparaMiguel",
    "LamparaMiguelSinPeana",
    "Lanza",
    "LanzaAncha",
    "LanzaAnchaPieza1",
    "LanzaAnchaPieza2",
    "LanzaAnchaPieza3",
    "LanzaAnchaPieza4",
    "LanzaPieza1",
    "LanzaPieza2",
    "Lanzapivotes",
    "Lapida",
    "Obelisco",
    "Lapida3",
    "LapidaAmazona",
    "LapidaBarbaro",
    "LapidaCaballero",
    "LapidaManuel",
    "LeonBronce",
    "Libro",
    "Libro2",
    "Libro3",
    "LibroPulsador",
    "LightEdge",
    "LightEdgePieza1",
    "LightEdgePieza2",
    "LightEdgePieza3",
    "Llave",
    "Llavecob",
    "Llavecobox",
    "Llavecutre",
    "LlaveDoblada",
    "Llavedor",
    "Llavepla",
    "Llavero",
    "LongSword",
    "LongSwordPieza1",
    "LongSwordPieza2",
    "LongSwordPieza3",
    "LuzDivinaFina",
    "LuzDivinaGorda",
    "Astillas1",
    "Astillas2",
    "Astillas3",
    "MagicShield",
    "MagicShield2",
    "MagicShield3",
    "MagicShieldBreak",
    "MandibulaSerpiente",
    "Manzana",
    "Martillo2",
    "Martillo",
    "Martillo2Pieza1",
    "Martillo2Pieza2",
    "Martillo3",
    "Martillo3Pieza1",
    "Martillo3Pieza2",
    "MartilloForjaPieza1",
    "MartilloForjaPieza2",
    "MartilloPieza1",
    "MartilloPieza2",
    "Maza",
    "Maza2",
    "Maza2Pieza1",
    "Maza2Pieza2",
    "Maza3",
    "Maza3Pieza1",
    "Maza3Pieza2",
    "MazaDoble",
    "MazaDoblePieza1",
    "MazaDoblePieza2",
    "Mazapiedra",
    "MazapiedraPieza1",
    "MazapiedraPieza2",
    "MazapiedraPieza3",
    "MazaPieza1",
    "MazaPieza2",
    "Menhir1",
    "Menhir2",
    "Menhir3",
    "Mesa",
    "MesaPieza1",
    "MesaPieza2",
    "MesaPieza3",
    "MesaPieza4",
    "MesaPieza5",
    "Mesita",
    "MesitaPieza1",
    "MesitaPieza2",
    "MesitaPieza3",
    "MesitaPieza4",
    "Meson",
    "MesonPieza1",
    "MesonPieza2",
    "Mesonroto",
    "Meteorito",
    "Monjecaliz",
    "Monjema",
    "Monjescudo",
    "Monjespada",
    "Mortero",
    "Naginata",
    "Naginata2",
    "Naginata2Pieza1",
    "Naginata2Pieza2",
    "Naginata2Pieza3",
    "NaginataPieza1",
    "NaginataPieza2",
    "Ninjato",
    "NinjatoPieza1",
    "NinjatoPieza2",
    "Nube",
    "ObeliscoGrande",
    "ObeliscoNevado",
    "OndaExpansiva",
    "Libroabierto2",
    "Libroabierto",
    "Orbe",
    "Orksword",
    "OrkswordPieza1",
    "OrkswordPieza2",
    "Pala",
    "Palanca1",
    "Palanca2",
    "Palanca3",
    "PalancaSuelo",
    "PalancaTimon",
    "Palangana",
    "Palancatortura",
    "Paletilla",
    "Panoplia",
    "PasarelaCorta",
    "PasarelaLarga",
    "Peanapiedra",
    "Pelele",
    "PeleleNevado",
    "Pendon1",
    "Pendon2",
    "Pendon3",
    "Pendon4",
    "Pendulo",
    "Pendulo2",
    "Pergamino2",
    "Pergamino",
    "Perola",
    "Phurbhu",
    "PhurbhuPieza1",
    "PhurbhuPieza2",
    "Pico",
    "PiedraNevada",
    "Piedra_01",
    "Piedra_02",
    "Piedra_03",
    "Piedra_04",
    "Piedra_05",
    "Piedra_06",
    "Piedra_07",
    "Piedra_08",
    "Piedra_09",
    "Piedra_10",
    "Piedra_Bar_seleccion",
    "Piedra_Glm_cl",
    "Piedra_Glm_ic",
    "Piedra_Glm_lv",
    "Piedra_Glm_mt",
    "Piedra_Glm_st",
    "PiedraInformativa",
    "PiedrasBarbaro",
    "PiedraNevadaCortada",
    "PinchoManuel",
    "PinchoMiguel",
    "Pinchos",
    "PinchoSotano",
    "Pivote",
    "Pivote2",
    "PivoteEnvenenado",
    "PlacaTallada",
    "Planta1",
    "Planta2",
    "Planta3",
    "Plantita",
    "PlataformaFernando",
    "Plataforma",
    "PlataformaRail",
    "Pluma",
    "Pocima100",
    "Pocima200",
    "Pocima25",
    "Pocima50",
    "PocimaTodo",
    "Polea",
    "PowerPotion",
    "PowerupGold",
    "PowerupSilver",
    "PuenteAdolfoDerecho",
    "PuenteAdolfoIzquierdo",
    "PuenteAurelio",
    "Puenteau_Plano",
    "PuenteFernando",
    "PuertaFernando",
    "PuertaMiguelDerecha",
    "PuertaMiguelIzquierda",
    "QueenSword",
    "QueenSwordPieza1",
    "QueenSwordPieza2",
    "QueenSwordPieza3",
    "Queso",
    "Rabano",
    "Rail",
    "Rail2",
    "Raiz",
    "Rama1",
    "Rama2",
    "RamaNevada",
    "Rastrillo",
    "Rastrillo2",
    "ReinaAurelio",
    "Reja",
    "Restos",
    "Reyaurelio",
    "RhinoClub",
    "RhinoClubPieza1",
    "RhinoClubPieza2",
    "Roca1Aurelio",
    "Roca2Aurelio",
    "Roca1",
    "Roca2",
    "Roca3",
    "RollodeCuerda",
    "Sablazo",
    "SablazoPieza1",
    "SablazoPieza2",
    "Saquito",
    "SawSword",
    "SawSwordPieza1",
    "SawSwordPieza2",
    "SectorVolcan",
    "SemiBolaRayos",
    "Semipuxero",
    "Seta",
    "Setas",
    "Shield_Kgt_seleccion",
    "Silla",
    "SillaPieza1",
    "SillaPieza2",
    "SillaPieza3",
    "SillaPieza4",
    "SillaPieza5",
    "SillaPieza6",
    "Skull",
    "Soporteantorcha",
    "SoporteOrbe",
    "SteelFeather",
    "SteelFeatherPieza1",
    "SteelFeatherPieza2",
    "SteelFeatherPieza3",
    "SteelFeatherPieza4",
    "Supositorio",
    "Suriken",
    "Tabla_l",
    "Tabla_rota",
    "Tabla_rota2",
    "Tabla_xl",
    "Tabla_xlpieza2",
    "Tabla_xPieza1",
    "Tablatortura",
    "Tablilla1",
    "Tablilla2",
    "Tablilla3",
    "Tablilla4",
    "Tablilla5",
    "Tablilla6",
    "Taburete",
    "Taburete_Dwf_seleccion",
    "TaburetePieza1",
    "TaburetePieza2",
    "TaburetePieza3",
    "TaburetePieza4",
    "TabureteSeleccion",
    "Tacita",
    "TaiSword",
    "TaiSwordPieza1",
    "TaiSwordPieza2",
    "TaiSwordPieza3",
    "TaiSwordPieza4",
    "Tapiz",
    "Tapiz2",
    "Tapiz3",
    "Tapiz4",
    "Tapiz5",
    "Tapiz6",
    "TapizAurelio",
    "TapizEscorpion",
    "Tapizkemado1",
    "Tapizkemado2",
    "TelaranyaCuadrada",
    "TelaranyaCuadrada2",
    "TelaranyaEsquina",
    "TelaranyaTriangular",
    "Telescopio",
    "Timon",
    "Tinaja",
    "Tintero",
    "Tocon",
    "Totem",
    "Totem2",
    "TinajaPieza1",
    "TinajaPieza2",
    "TinajaPieza3",
    "TinajaPieza4",
    "TinajaPieza5",
    "Trampilla",
    "Tridente",
    "TridentePieza1",
    "TridentePieza2",
    "Trillo",
    "Tronchy",
    "Tronco",
    "TroncoGrande",
    "TroncoNevado",
    "TroncoTrampa",
    "Tronoliso",
    "TronoEscarabeu",
    "Tronera",
    "Tronera2",
    "Trono",
    "TronoManuel",
    "Tumbacobra",
    "Lapidareina",
    "Lapidarey",
    "Vagoneta",
    "VampShield",
    "VampShieldPieza1",
    "VampShieldPieza2",
    "VampWeapon",
    "VampWeaponPieza1",
    "VampWeaponPieza2",
    "Varilla",
    "Varillaancha",
    "Varita1",
    "Varita1Pieza1",
    "Varita1Pieza2",
    "Varita2",
    "Varita2Pieza1",
    "Varita2Pieza2",
    "Varita5",
    "Varita5Pieza1",
    "Varita5Pieza2",
    "Varita6",
    "Varita6Pieza1",
    "Varita6Pieza2",
    "Varita7",
    "Varita7Pieza1",
    "Varita7Pieza2",
    "Velon",
    "Viga",
    "VigaPlana",
    "Vigaro1",
    "Vigaro2",
    "Vampire_Head",
    "Vortice1",
    "Vortice2",
    "LlaveBlanca",
    "Xkorpyon",
    "LlaveAmarilla",
    "LlaveAmarilla_Aura",
    "Yunque",
    "Zocalo1",
    "Zocalo2",
    "Zocalo3",
    "ZocaloSerpiente",
    "ZocaloSuelo",
    "ZocaloTimon",
    "Rastrillo3",
    "Rastrillo32",
    "IceWand",
    "trozogran1",
    "trozogran10",
    "trozogran11",
    "trozogran12",
    "trozogran2",
    "trozogran3",
    "trozogran4",
    "trozogran5",
    "trozogran6",
    "trozogran7",
    "trozogran8",
    "trozogran9",
    "trozope1",
    "trozope2",
    "trozope3",
    "trozope4",
    "trozope5",
    "trozope6",
    "trozope7",
    "trozope8",
    "Rastrillo10",
    "Rastrillo102",
    "BarraCareto",
    "BarraElefante",
    "BarraNarizon",
    "BarraPajaro",
    "AlabardaPieza3",
    "puertagran",
    "puertamed",
    "puertapeque1",
    "puertapeque2",
    "puertapeque3",
    "puertapeque4",
    "Carcaj1",
    "Carcaj2",
    "Carcaj3",
    "CarcajEnvenenado1",
    "CarcajEnvenenado2",
    "CarcajEnvenenado3",
    "CarcajFuego1",
    "CarcajFuego2",
    "CarcajFuego3",
]



# Module 'BUIxc'
from __future__ import annotations

import Bladex.__sub__.b_types as __bt


def B_BarWidget_B_BAR_Backward(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_B_BAR_Both(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_B_BAR_Expand(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_B_BAR_Fordward(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_B_BAR_Horizontal(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_B_BAR_Vertical(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetBackgroundAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetBackgroundColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetLimits(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetMovementMode(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetOrientation(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetPosition(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetPositionPercentage(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetValue(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetBackgroundAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetBackgroundColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetLimits(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetMovementMode(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetOrientation(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetPosition(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetPositionPercentage(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetValue(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitmapWidget_SetBitmap(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitmapWidget_SetSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FontServer_CreateBFont(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FontServer_DestroyBFont(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FontServer_GetBFont(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Font_GetFirst(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Font_GetHeight(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Font_GetLast(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Font_GetPointer(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Font_GetTextWidth(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Font___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_AddWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_GetWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_GetWidgetPosition(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_GetWidget_Idx(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_MoveWidgetRel(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_MoveWidgetRel_Idx(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_MoveWidgetTo(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_MoveWidgetTo_Idx(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_RecalcLayout(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_RemoveWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_RemoveWidget_Idx(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_SetSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_nWidgets(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_GridWidget_AddWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_GridWidget_DefSizeChanged(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_GridWidget_GetWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_GetBorder(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_GetBorderColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_GetSolid(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetBitmap(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetBitmapCoords(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetBitmapIndex(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetBorder(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetBorderColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetSolid(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_AddBar(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_AddValue(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_Draw(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_GetBar(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_GetMovementMode(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_GetOrientation(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_GetPosition(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_GetPositionPercentage(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_GetnBars(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_SetMovementMode(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_SetOrientation(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_SetPosition(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_SetPositionPercentage(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_SetSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_Bottom(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_HCenter(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_Horizontal(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_Left(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_Right(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_Top(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_VCenter(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_Vertical(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetAutoSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetBackgroundAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetBackgroundColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetJustification(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetOrientation(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetTextData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetTextOriginX(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetTextOriginY(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetAutoSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetBackgroundAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetBackgroundColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetFont(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetJustification(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetOrientation(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetText(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetTextOriginX(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetTextOriginY(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_AcceptsFocus(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_AddAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_AddLabel(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_AbsoluteBottom(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_AbsoluteLeft(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_AbsoluteRight(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_AbsoluteTop(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_Bottom(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_HCenter(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_HRelative(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_Left(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_Right(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_Top(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_VCenter(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_VRelative(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_LAB_Bottom(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_LAB_HCenter(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_LAB_Left(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_LAB_Right(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_LAB_Top(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_LAB_VCenter(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_DefDraw(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_DefSizeChanged(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetAutoScale(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetClipChildren(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetClipDraw(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetHasFocus(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetPointer(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetPosition(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetVisible(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_MultiplyAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_Name(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_ProcessCommand(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_RecalcLabelLayout(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetAutoScale(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetClipChildren(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetClipDraw(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetDrawFunc(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetHasFocus(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetSizeChangedFunc(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetVisible(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def CreateFrameWidgetFromPtr(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def CreateNULLWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def CreateRectWidgetFromPtr(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def CreateTextWidgetFromPtr(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def CreateWidgetFromPtr(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def Draw(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_BarWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_BitmapWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_FontServer(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_FrameWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_GridWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_RectWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_StackBarWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_TextWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_Widget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_BarWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_BitmapWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_FontServer(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_FrameWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_GridWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_RectWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_StackBarWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_TextWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_Widget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...



from __future__ import annotations

from .b_types import *


class B_PyChar:
    def __init__(self, /) -> None:
        self.DieFall: float
        self.DistStop: float
        self.DistStop2: float
        self.DistStopMaxFactor: float
        self.Fov: float
        self.HeadControlled: int
        self.HearMinVolume: float
        self.HighArmour: str
        self.IntName: str
        self.Jcost: float
        self.LowArmour: str
        self.MaxCombatDist: float
        self.MaxFall: float
        self.MaxGrab: float
        self.MaxSeeDist: float
        self.MaxStair: float
        self.MaxTake1: float
        self.MaxTake2: float
        self.MaxTake3: float
        self.MaxTake4: float
        self.MaxTake5: float
        self.MedArmour: str
        self.MedGrab: float
        self.Min2Grab: float
        self.MinTake: float
        self.MovBkwdSpeedInStrafe: float
        self.MovFrwdSpeedInStrafe: float
        self.NaturalWeapons: int
        self.NoArmour: str
        self.Reach: float
        self.TurnSpeed: float

    def AddAttack(self, attack_name: str, anm_name: str, /) -> Bool:
        ...

    def AddEnergyLevel(self, anm_name: str, level: int, /) -> Bool:
        ...

    def AddLevels(
        self, anm_name: str, allow_attack_lv: int, allow_destructor_lv: int, /
    ) -> Bool:
        ...

    @overload
    def AllowAttack(
        self,
        attack_name: str,
        keys: Literal["R", "L", "F", "B", "A", "D"],
        previous: str,
        previous_negative: str,
        window_name: str,
        weapon_kind: Literal["1H", "2W", "AXE", "SP"] = "1H",
        /,
    ) -> Bool:
        ...

    @overload
    def AllowAttack(
        self,
        attack_name: str,
        keys: str,
        previous: str,
        previous_negative: str,
        window_name: str,
        weapon_kind: str = "1H",
        /,
    ) -> Bool:
        ...

    def AllowAttack(
        self,
        attack_name: str,
        keys: str,
        previous: str,
        previous_negative: str,
        window_name: str,
        weapon_kind: str = "1H",
        /,
    ) -> Bool:
        """
        :keys Modifiers:
            R+L - Simultaneous press\n
            !F - Should not be pressed\n
            &F - Should be already pressed
        """
        ...

    @overload
    def AssignTrail(
        self,
        attack_name: str,
        unknown: Literal[""],
        trail_name: Literal[
            "EstelaAmarilla1", "EstelaAzul1", "EstelaGris1", "EstelaRoja1"
        ],
        /,
    ) -> Bool:
        ...

    @overload
    def AssignTrail(self, attack_name: str, unknown: str, trail_name: str, /) -> Bool:
        ...

    def AssignTrail(self, attack_name: str, unknown: str, trail_name: str, /) -> Bool:
        ...

    def AttackTypeFlag(self, attack_name: str, flag: int, /) -> Bool:
        ...

    def AttackWindow(
        self, anm_name: str, window_start: float, window_end: float, window_name: str, /
    ) -> Bool:
        ...

    def ChangeAnimation(self, old_anm_name: str, new_anm_name: str, /) -> Bool:
        ...

    def LoadAllAnimations(self, /) -> Bool:
        ...

    def MetaAttack(self, meta_attack_name: str, attack_name: str, /) -> Bool:
        ...

    def SetAnmDefaultPrefix(self, prefix: str, /) -> Bool:
        ...

    def SetCDSphere(self, index: int, height: float, radius: float, /) -> Bool:
        ...

    def SetNCDSpheres(self, number: int, /) -> Bool:
        ...



# Module 'Traps_C'
from __future__ import annotations

import Bladex.__sub__.b_types as __bt


def AddAllObjects(*args: __bt.todo) -> __bt.todo:
    """SearchSector()
    Funcion para buscar una habitacion"""
    ...


def AddAllPersons(*args: __bt.todo) -> __bt.todo:
    """SearchSector()
    Funcion para buscar una habitacion"""
    ...


def AddName(*args: __bt.todo) -> __bt.todo:
    """SearchSector()
    Funcion para buscar una habitacion"""
    ...


def AddSector(*args: __bt.todo) -> __bt.todo:
    """InitSector()
    Funcion para inicializar"""
    ...


def AddSplineNode(*args: __bt.todo) -> __bt.todo:
    """AddSplineNode(spline,pos,tang_i,tang_f)
    Funcion para añadir un nodo al spline"""
    ...


def ClearSpline(*args: __bt.todo) -> __bt.todo:
    """ClearSpline()
    Funcion para borrar los nodos del spline"""
    ...


def CloseSpline(*args: __bt.todo) -> __bt.todo:
    """CloseSpline()
    Funcion para cerrar la spline"""
    ...


def CreateSpline(*args: __bt.todo) -> __bt.todo:
    """CreateSpline()
    Funcion para crear una spline"""
    ...


def DeleteMaxPath(*args: __bt.todo) -> __bt.todo:
    """GetSplinePos(spline,time)
    Funcion para obtener la posicion de una spline"""
    ...


def GetMaxPathPosition(*args: __bt.todo) -> __bt.todo:
    """GetSplinePos(spline,time)
    Funcion para obtener la posicion de una spline"""
    ...


def GetSplinePos(*args: __bt.todo) -> __bt.todo:
    """GetSplinePos(spline,time)
    Funcion para obtener la posicion de una spline"""
    ...


def InitSector(*args: __bt.todo) -> __bt.todo:
    """AddSector()
    Funcion para añadir una nueva habitacion"""
    ...


def IsValidEntity(*args: __bt.todo) -> __bt.todo:
    """SearchSector()
    Funcion para buscar una habitacion"""
    ...


def LoadMaxPath(*args: __bt.todo) -> __bt.todo:
    """GetSplinePos(spline,time)
    Funcion para obtener la posicion de una spline"""
    ...


def Prueba(*args: __bt.todo) -> __bt.todo:
    """ClonarFlecha()
    Funcion para clonar una flecha clavada con el nombre original"""
    ...



# Module 'Raster'
from __future__ import annotations

import typing as __t

import Bladex.__sub__.b_types as __bt


def BmpHandle(bmp_name: str, /) -> int:
    """"""
    ...


def BmpName(bmp_handle: int, /) -> str:
    """"""
    ...


def ClassIdName() -> str:
    """"""
    ...


def Cls(r: int, g: int, b: int, /) -> None:
    """"""
    ...


def DrawBitmap(bmp_handle: int, w: int, h: int, /) -> None:
    """"""
    ...


@__t.overload
def DrawImage(
    w: int, h: int, color_channel: str, align: str, image_data: int, /
) -> None:
    """"""
    ...


@__t.overload
def DrawImage(
    w: int,
    h: int,
    color_channel: __t.Literal["RGB", "BGR"],
    align: __t.Literal[
        "Cover",
        "Native",
        "Normal",
        "ScaledCentered",
        "ScaledCentered2",
        "Stretch",
        "UpsideDown",
    ],
    image_data: int,
    /,
) -> None:
    """"""
    ...


def DrawImage(*args: __t.Any, **kwargs: __t.Any) -> __t.Any:
    """"""
    ...


def FullScreen() -> __bt.Bool:
    """"""
    ...


def GetAlpha() -> float:
    """"""
    ...


def GetBrightness() -> float:
    """"""
    ...


def GetClipActive() -> __bt.Bool:
    """"""
    ...


def GetClipWindow() -> __t.Tuple[int, int, int, int]:
    """
    :return: (x, y, w, h)
    """
    ...


def GetContrast() -> float:
    """"""
    ...


def GetCurrentMode() -> __t.Tuple[int, int, int, int, int]:
    """
    :return: (depth, w, h, flags, frequency)
    """
    ...


def GetDomeColor() -> __bt.RGBColor:
    """"""
    ...


def GetGammaCorrection() -> float:
    """"""
    ...


def GetImage(
    x: int,
    y: int,
    w: int,
    h: int,
    color_channel: __t.Union[__t.Literal["RGB", "BGR"], __bt.str_],
    align: __t.Literal[
        "Cover",
        "Native",
        "Normal",
        "ScaledCentered",
        "ScaledCentered2",
        "Stretch",
        "UpsideDown",
    ],
    image_size: int,
    image_data: int,
    /,
) -> __bt.Bool:
    """"""
    ...


def GetPosition() -> __bt.Vector2:
    """"""
    ...


def GetRasterParameter(parameter: str, /) -> str:
    """"""
    ...


def GetSize() -> __t.Tuple[int, int]:
    """
    :return: (w, h)
    """
    ...


def GetTextAlpha() -> float:
    """"""
    ...


def GetTextBlur() -> __t.Tuple[int, int, int, int]:
    """
    :return: (blurLeft, blurTop, blurRight, blurBottom)
    """
    ...


def GetTextBlurAlpha() -> float:
    """"""
    ...


def GetTextMode() -> int:
    """"""
    ...


def GetTextScale() -> __t.Tuple[float, float]:
    """
    :return: (scale_x, scale_y)
    """
    ...


def GetTextShadow() -> __t.Tuple[int, int]:
    """
    :return: (x_shadow, y_shadow)
    """
    ...


def GetTextureInfo(index: int, /) -> __t.Tuple[int, int, int]:
    """
    :return: (w, h, depth)
    """
    ...


def GetVideoModeDscr(mode_index: int, /) -> __t.Tuple[int, int, int, int, int]:
    """
    :return: (depth, w, h, flags, frequency)
    """
    ...


def GetWindowSize() -> __t.Tuple[int, int]:
    """
    :return: (w, h)
    """
    ...


def Line(x1: int, y1: int, x2: int, y2: int, /) -> None:
    """"""
    ...


def LineTo(x: int, y: int, /) -> None:
    """"""
    ...


def Rectangle(x1: int, y1: int, x2: int, y2: int, /) -> None:
    """"""
    ...


def RemoveBackgroundImage() -> None:
    """"""
    ...


def SetAlpha(alpha: float, /) -> None:
    """"""
    ...


def SetBackgroundImage(
    w: int,
    h: int,
    color_channel: __t.Literal["RGB"],
    is_normal: __t.Literal["Normal"],
    align: __t.Literal[
        "Cover",
        "Stretch",
        "ScaledCentered",
        "VerticalStretch",
    ],
    image_data: int,
    /,
) -> None:
    """"""
    ...


def SetBrightness(v: float, /) -> None:
    """"""
    ...


def SetClipActive(active: int, /) -> None:
    """"""
    ...


def SetClipWindow(x: int, y: int, w: int, h: int, /) -> None:
    """"""
    ...


def SetContrast(v: float, /) -> None:
    """"""
    ...


def SetDomeColor(r: int, g: int, b: int, /) -> None:
    """"""
    ...


def SetFillColor(r: int, g: int, b: int, /) -> None:
    """"""
    ...


def SetFlags(flags: int, /) -> None:
    """"""
    ...


def SetFont(font_pointer: int, /) -> None:
    """"""
    ...


def SetGammaCorrection(v: float, /) -> None:
    """"""
    ...


def SetPenColor(r: int, g: int, b: int, /) -> None:
    """"""
    ...


def SetPosition(x: int, y: int, /) -> None:
    """"""
    ...


def SetRasterParameter(parameter: str, value: str, /) -> __bt.Bool:
    """"""
    ...


def SetTextAlpha(v: float, /) -> None:
    """"""
    ...


def SetTextBlur(
    blurLeft: int, blurTop: int, blurRight: int, blurBottom: int, /
) -> None:
    """"""
    ...


def SetTextBlurAlpha(v: float, /) -> None:
    """"""
    ...


def SetTextBlurColor(r: int, g: int, b: int, /) -> None:
    """"""
    ...


def SetTextColor(r: int, g: int, b: int, /) -> None:
    """"""
    ...


def SetTextMode(mode: int, /) -> None:
    """SetTextMode(3)"""
    ...


def SetTextScale(scale_x: float, scale_y: float, /) -> None:
    """"""
    ...


def SetTextShadow(x_shadow: int, y_shadow: int, /) -> None:
    """"""
    ...


def SetVideoMode(mode: int, /) -> __bt.Bool:
    """"""
    ...


def SetVideoSettings(gamma: float, contrast: float, brightness: float, /) -> None:
    """"""
    ...


def SetWindowSize(w: int = -1, h: int = -1, /) -> __bt.Bool:
    """"""
    ...


def SolidRectangle(x1: int, y1: int, x2: int, y2: int, /) -> None:
    """"""
    ...


def SwapBuffers() -> None:
    """"""
    ...


def SysWrite(x: int, y: int, text: str, r: int, g: int, b: int, /) -> None:
    """"""
    ...


def UnifyRenderBuffers() -> None:
    """"""
    ...


def WriteText(text: str, /) -> __bt.Bool:
    """"""
    ...


def nTextures() -> int:
    """"""
    ...


def nVideoModes() -> int:
    """"""
    ...


#########
# reissue


def DrawResizeImage(*args: __bt.todo) -> __bt.Bool:
    """*reissue only*"""
    ...


def GetScaledCenteredSizeFactor(*args: __bt.todo) -> __bt.Bool:
    """*reissue only*"""
    ...


def GetUnscaledSize(*args: __bt.todo) -> __bt.Bool:
    """*reissue only*"""
    ...


def ResetScale(*args: __bt.todo) -> __bt.Bool:
    """*reissue only*"""
    ...



# Module 'Console'
from __future__ import annotations

import Bladex.__sub__.b_types as __bt


def ConsoleOutput(text: str, /) -> __bt.Bool:
    """ConsoleOutput(string texto)
    Muestra texto por la consola."""
    ...


def ConsoleVisible() -> __bt.Bool:
    """ConsoleVisible()
    Indica si la consola es visible."""
    ...


def ShowConsole(sw: __bt.Bool, /) -> __bt.Bool:
    """ShowConsole(int sw)
    Muestra/oculta la consola."""
    ...
